      REM "Rainbow Snake"
      REM (Originally) intended for Android phones
      REM Works with BB4W and BBCSDL
      REM Version 1.01 // 28-Aug-2018

      OSCLI "ESC OFF"

      MODE 8 : OFF

      ProgTitle$ = "Rainbow Snake"
      ProgVer$   = "1.01"

      BB4W% = (INKEY(-256) == &57)

      IF NOT BB4W% THEN
        OSCLI "SYS 4"  : REM Effectively disable SDL_MULTIGESTURE (prevents zooming & panning)
        FontFile$ = @lib$ + "DejaVuSans.ttf"
        F% = OPENIN( FontFile$ )
        CLOSE#F%
        IF F% THEN
          OSCLI "font " + FontFile$ + ", 20"
        ENDIF
        IF (@platform% AND &40) THEN PROCerror( "Not compatible with 64-bit BBCSDL" )
        CASE (@platform% AND &F) OF
          WHEN 2 : PROCerror( "Not compatible with MacOS" )
          WHEN 4 : PROCerror( "Not compatible with iOS" )
        ENDCASE
      ENDIF

      ON CLOSE QUIT
      ON ERROR PROCerror( REPORT$ + " at line " + STR$ERL )

      HIMEM = LOMEM + 8*&100000
      HIMEM = (HIMEM + 3) AND -4

      Crunched% = FNCrunched : REM TRUE if program is crunched, FALSE if otherwise

      ShowFPS% = FALSE : REM set to TRUE to display the frame rate during the game

      IF BB4W% THEN
        SYS "SetWindowText", @hwnd%, ProgTitle$ + " " + ProgVer$
      ELSE
        SYS "SDL_SetWindowTitle", @hwnd%, ProgTitle$ + " " + ProgVer$
      ENDIF

      REM -------------------------------------
      IF BB4W% THEN
        GetTicks$ = "GetTickCount"
      ELSE
        GetTicks$ = "SDL_GetTicks"
      ENDIF
      REM -------------------------------------
      REM This code segment is the work of RTR:
      p = PI
      CASE !^p OF
        WHEN &2168C235: cpu$ = "x86" : ARM% = FALSE
        WHEN &54442D18: cpu$ = "arm" : ARM% = TRUE
        OTHERWISE: QUIT
      ENDCASE
      REM -------------------------------------

      ScrW% = 360 : REM Screen/window width in pixels

      REM Set the height dimension for our main rendering surface:
      IF BB4W% THEN
        REM Screen (window) height set to 640 pixels if running under BB4W
        ScrH% = 640
      ELSE
        DIM mode{ fmt%, w%, h%, r%, d% }
        SYS "SDL_GetCurrentDisplayMode", 0, mode{}
        IF mode.h% > mode.w% THEN
          ScrH% = (INT(mode.h%/mode.w% * ScrW%) + 1) AND -2 : REM ensure ScrH% is divisible by 2
        ELSE
          ScrH% = 640
        ENDIF
      ENDIF

      PROCFixWindowSize : REM works for both BB4W and BBCSDL

      VDU 23, 22, ScrW%; ScrH%; 8, 16, 16, 0 : OFF

      IF POS : REM Well, why not.

      REM (BBCSDL) Disable colour dithering on 16bpp display:
      REM IF NOT BB4W% THEN
      REM SYS "glDisable", &BD0, @memhdc% <--- ACTUALLY, LET'S KEEP DITHERING ENABLED!
      REM ENDIF

      REM Get addresses of x86 or ARM machine code routines:
      ClipBitmap%       = FNread_data( "clipbitmap_"             + cpu$ )
      Clr%              = FNread_data( "clr16_360xh_"            + cpu$ )
      ConvBmRGB565%     = FNread_data( "convbmrgb8888torgb565_"  + cpu$ ) : REM convert a 32-bit ARGB8888 bitmap to RGB565
      ConvPxlRGB565%    = FNread_data( "convpxlrgb8888torgb565_" + cpu$ ) : REM convert a 24-bpp RGB888 single colour value to RGB565 (no dithering!)
      ConvBMP24%        = FNread_data( "convbmp24torgb8888_"     + cpu$ ) : REM convert a 24-bpp RGB888 BMP to raw 32-bpp ARGB8888
      BPlot%            = FNread_data( "bplot16_"                + cpu$ )
      Plot%             = FNread_data( "plot16_"                 + cpu$ )
      PlotAvg%          = FNread_data( "plot16_avg_"             + cpu$ )
      PlotShape%        = FNread_data( "plot16_shape_"           + cpu$ )
      PlotShapeBlend%   = FNread_data( "plot16_shapeblend_"      + cpu$ )
      PlotScale%        = FNread_data( "plot16_scale_"           + cpu$ )
      PlotScaleBlend%   = FNread_data( "plot16_scaleblend_"      + cpu$ )
      PlotRotateScale%  = FNread_data( "plot16_rotatescale_"     + cpu$ )
      ReadPixel%        = FNread_data( "readpixel16_"            + cpu$ )
      ScoreDigits12x20% = FNread_data( "digits12x20" ) : REM 10 12x20 bitmaps for character numbers 0 to 9 (used for FPS display)

      SinTbl% = FNBuildSineTable : REM used by the ARM version of PlotRotateScale

      REM Convert the 32bpp 12x20 'digit' bitmaps to 16bpp RGB565
      REM (the original 32bpp bitmaps get overwritten by their respective 16bpp versions, which is safe to do):
      FOR I% = 0 TO 9
        A% = ScoreDigits12x20% + ScoreDigits12x20%!(4*I%) : REM source address
        B% = A% : REM destination address (set here to source address)
        C% = 12 : REM bitmap width
        D% = 20 : REM bitmap height
        CALL ConvBmRGB565%
      NEXT I%

      REM Load the single, combined resource file (graphics, sound effects, etc.):
      DataFile$ = @dir$ + "RainbowSnakeData.DAT"
      F% = OPENIN( DataFile$ )
      IF F% = 0 THEN PROCerror( "Can't find file RainbowSnakeData.DAT" )
      S% = EXT#F%
      CLOSE#F%
      DIM Data% S%+3
      Data% = (Data% + 3) AND -4
      OSCLI "LOAD """ + DataFile$ + """ " + STR$~Data%

      HiScoreFile$ = @dir$ + "rainbowsnakehiscore.DAT"
      REM Load the 'Hi-Score' data file (or create a new one if it doesn't already exist):
      HiScore% = 0
      F% = OPENIN( HiScoreFile$ )
      IF F% <> 0 THEN
        INPUT#F%, HiScore%
      ELSE
        CLOSE#F%
        F% = OPENOUT( HiScoreFile$ )
        HiScore% = 10
        PRINT#F%, HiScore%
      ENDIF
      CLOSE#F%

      REM Create 'rainbow' colour table from which the snake's body segments get their colour.
      REM Inititally, the colours are defined as 24bpp RGB888 (&xxRRGGBB) format, but are subsequently
      REM converted to 16bpp RGB565.
      DIM ColTbl%(15)
      ColTbl%(0)  = &FF0000
      ColTbl%(1)  = &FF0065
      ColTbl%(2)  = &FF00E1
      ColTbl%(3)  = &D600FF
      ColTbl%(4)  = &6D00FF
      ColTbl%(5)  = &1000FF
      ColTbl%(6)  = &003CFF
      ColTbl%(7)  = &00B5FF
      ColTbl%(8)  = &00FFF6
      ColTbl%(9)  = &00FF9E
      ColTbl%(10) = &00FF34
      ColTbl%(11) = &11FF00
      ColTbl%(12) = &76FF00
      ColTbl%(13) = &E1FF00
      ColTbl%(14) = &FFD300
      ColTbl%(15) = &FF5D00

      REM Now convert the colours to RGB565:
      FOR I% = 0 TO 15
        A% = ColTbl%(I%)
        ColTbl%(I%) = USR( ConvPxlRGB565% )
      NEXT I%

      REM Create the main rendering surface bitmap (16bpp RGB565):
      DIM bmp{a%, w%, h%}
      bmp% = FNCreateBMP_RGB565(ScrW%, ScrH%)
      bmp.a% = bmp% + 70 : REM bmp.a% contains address of first byte of bitmap (header size is 70 bytes)
      bmp.w% = ScrW%
      bmp.h% = ScrH%

      PROCConvBMP24( FNGetDataAddr(Data%, "splashscreen"),       SplashScreenBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "startscreen"),        StartScreenBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "startbutton"),        StartButtonBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "snakehead"),          SnakeHeadBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "snakebody"),          SnakeBodyBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "strawb"),             StrawbBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "clockwisearrow"),     ClockwiseArrowBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "anticlockwisearrow"), AnticlockwiseArrowBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "particle"),           ParticleBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "point"),              TrailDotBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_0_20x27"),      ScoreDigit0Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_1_20x27"),      ScoreDigit1Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_2_20x27"),      ScoreDigit2Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_3_20x27"),      ScoreDigit3Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_4_20x27"),      ScoreDigit4Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_5_20x27"),      ScoreDigit5Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_6_20x27"),      ScoreDigit6Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_7_20x27"),      ScoreDigit7Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_8_20x27"),      ScoreDigit8Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "digit_9_20x27"),      ScoreDigit9Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_0_26x37"),   BigScoreDigit0Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_1_26x37"),   BigScoreDigit1Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_2_26x37"),   BigScoreDigit2Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_3_26x37"),   BigScoreDigit3Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_4_26x37"),   BigScoreDigit4Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_5_26x37"),   BigScoreDigit5Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_6_26x37"),   BigScoreDigit6Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_7_26x37"),   BigScoreDigit7Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_8_26x37"),   BigScoreDigit8Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "bigdigit_9_26x37"),   BigScoreDigit9Bm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "eye"),                EyeBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "tongue"),             TongueBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "splash"),             SplashBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "score"),              ScoreBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "hiscore"),            HiScoreBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "welldone"),           WellDoneBm{} )
      PROCConvBMP24( FNGetDataAddr(Data%, "canyoubeat"),         CanYouBeatBm{} )
      IF BB4W% THEN PROCConvBMP24( FNGetDataAddr(Data%, "info"), InfoBm{} )

      SoundFX% = TRUE

      DIM SoundSample{ slurp{w%,s%,p%}, hiss{w%,s%,p%}, pop{w%,s%,p%}, click{w%,s%,p%}, ding{w%,s%,p%} }

      REM .w% --> WAV file address
      REM .s% --> size of WAV file
      REM .p% --> pointer to (possibly converted) WAV file (will be same as w% if under BB4W)

      SoundSample.slurp.w% = FNGetDataAddr( Data%, "slurp" )
      SoundSample.slurp.s% = FNGetDataChunkSize( Data%, "slurp" )
      SoundSample.hiss.w%  = FNGetDataAddr( Data%, "hiss" )
      SoundSample.hiss.s%  = FNGetDataChunkSize( Data%, "hiss" )
      SoundSample.pop.w%   = FNGetDataAddr( Data%, "pop" )
      SoundSample.pop.s%   = FNGetDataChunkSize( Data%, "pop" )
      SoundSample.click.w% = FNGetDataAddr( Data%, "click" )
      SoundSample.click.s% = FNGetDataChunkSize( Data%, "click" )
      SoundSample.ding.w%  = FNGetDataAddr( Data%, "ding" )
      SoundSample.ding.s%  = FNGetDataChunkSize( Data%, "ding" )

      IF NOT BB4W% THEN
        `SDL_LoadWAV_RW`       = FNGetProcAddress("SDL_LoadWAV_RW")
        `SDL_QueueAudio`       = FNGetProcAddress("SDL_QueueAudio")
        `SDL_ClearQueuedAudio` = FNGetProcAddress("SDL_ClearQueuedAudio")
        `SDL_PauseAudioDevice` = FNGetProcAddress("SDL_PauseAudioDevice")
        DIM AudioSpec{freq%, format%, channels&, silence&, samples{l&,h&}, size%, callback%, userdata%}
        AudioSpec.freq% = 44100
        AudioSpec.format% = &8010 : REM AUDIO_S16LSB
        AudioSpec.channels& = 2
      ENDIF

      SoundSample.slurp.p% = FNLoadSoundFromMem( SoundSample.slurp.w%, SoundSample.slurp.s% )
      SoundSample.hiss.p%  = FNLoadSoundFromMem( SoundSample.hiss.w%,  SoundSample.hiss.s%  )
      SoundSample.pop.p%   = FNLoadSoundFromMem( SoundSample.pop.w%,   SoundSample.pop.s%   )
      SoundSample.click.p% = FNLoadSoundFromMem( SoundSample.click.w%, SoundSample.click.s% )
      SoundSample.ding.p%  = FNLoadSoundFromMem( SoundSample.ding.w%,  SoundSample.ding.s%  )

      DIM ScoreDigitBm%(9)
      ScoreDigitBm%(0) = ScoreDigit0Bm{}.a%
      ScoreDigitBm%(1) = ScoreDigit1Bm{}.a%
      ScoreDigitBm%(2) = ScoreDigit2Bm{}.a%
      ScoreDigitBm%(3) = ScoreDigit3Bm{}.a%
      ScoreDigitBm%(4) = ScoreDigit4Bm{}.a%
      ScoreDigitBm%(5) = ScoreDigit5Bm{}.a%
      ScoreDigitBm%(6) = ScoreDigit6Bm{}.a%
      ScoreDigitBm%(7) = ScoreDigit7Bm{}.a%
      ScoreDigitBm%(8) = ScoreDigit8Bm{}.a%
      ScoreDigitBm%(9) = ScoreDigit9Bm{}.a%

      DIM BigScoreDigitBm%(9)
      BigScoreDigitBm%(0) = BigScoreDigit0Bm{}.a%
      BigScoreDigitBm%(1) = BigScoreDigit1Bm{}.a%
      BigScoreDigitBm%(2) = BigScoreDigit2Bm{}.a%
      BigScoreDigitBm%(3) = BigScoreDigit3Bm{}.a%
      BigScoreDigitBm%(4) = BigScoreDigit4Bm{}.a%
      BigScoreDigitBm%(5) = BigScoreDigit5Bm{}.a%
      BigScoreDigitBm%(6) = BigScoreDigit6Bm{}.a%
      BigScoreDigitBm%(7) = BigScoreDigit7Bm{}.a%
      BigScoreDigitBm%(8) = BigScoreDigit8Bm{}.a%
      BigScoreDigitBm%(9) = BigScoreDigit9Bm{}.a%

      BfVars% = FNmalloc( 32 )
      BfVars%!0 = bmp.a%
      BfVars%!4 = bmp.w%
      BfVars%!8 = bmp.h%

      BmVars% = FNmalloc( 32 )
      ClipVars% = FNmalloc( 64 )
      ClipVars%!0 = ClipBitmap%

      MaxTrailDots% = 200
      DIM TrailDot{(MaxTrailDots%-1) active%, x%, y%, col%, opacity, d}

      MaxSegments% = 500
      DIM segX(MaxSegments%-1), segY(MaxSegments%-1), segD(MaxSegments%-1)
      segDist% = 12 : REM body segment separation distance
      REM segD() is a segment's distance to the next body segment (will usually be equal to segDist%)

      MaxExpParticles% = 10 * MaxSegments%
      DIM ExpParticleX( MaxExpParticles%-1 )
      DIM ExpParticleY( MaxExpParticles%-1 )
      DIM ExpParticleXV( MaxExpParticles%-1 )
      DIM ExpParticleYV( MaxExpParticles%-1 )
      DIM ExpParticleCol%( MaxExpParticles%-1 )

      NumFoodExpParticles% = 50
      DIM FoodParticle{( NumFoodExpParticles% ) active%, x, y, dx, dy, scale, dscale }

      PROCShowBlankScreen(100)
      PROCShowSplashScreen(300)

      REPEAT
        PROCShowBlankScreen(50)
        PROCStartScreen
        PROCShowBlankScreen(50)
        PROCMain
      UNTIL FALSE
      END
      :
      :
      :
      :
      DEF PROCMain

      LOCAL A%, B%, C%, D%, E%, F%, G%, H%, I%, J%, K%, L%, M%
      LOCAL N%, O%, P%, Q%, R%, S%, T%, U%, V%, W%, X%, Y%, Z%
      LOCAL dead%, frames%, frameRate%, flushKbBuf%
      LOCAL time%, time0%, time00%, dt
      LOCAL score%, segments%
      LOCAL dx, dy, dxn, dyn, d, l
      LOCAL snake{}, food{}, welldone{}, tongue{}

      DIM snake{ x, y, angle, speed }
      DIM food{new%, delay%, active%, x%, y%, scale, dscale, ddscale}
      DIM welldone{active%, theta, dtheta}
      DIM tongue{active%, delay%, theta, dtheta}

      PROCResetSnake

      dead% = FALSE

      frames% = 0
      frameRate% = 0

      flushKbBuf% = 0

      welldone.active% = FALSE
      welldone.theta = 0
      welldone.dtheta = 0.5

      hiscorebeaten% = FALSE

      tongue.active% = FALSE
      tongue.delay% = 0
      tongue.theta = 0
      tongue.dtheta = 4.0

      FOR I% = 0 TO MaxTrailDots%-1
        TrailDot{(I%)}.active% = FALSE
      NEXT I%
      pointindex% = 0

      bgCol% = &114F : REM RGB565 dark blue

      *REFRESH OFF

      SYS GetTicks$ TO time0%
      time00% = time0%

      REPEAT
  
        SYS GetTicks$ TO time%
        dt = (time% - time0%) / 500
        time0% = time%
  
        REM Enter a CPU-friendly spin loop if window loses focus:
        IF NOT FNCheckForWindowFocus THEN
          SYS GetTicks$ TO time0%
          *REFRESH OFF
        ENDIF
  
        REM Clear screen:
        A% = !BfVars% : B%=ScrH% : C% = bgCol% : CALL Clr%
  
        REM Draw the fading colour 'points' shed by the snake segments:
        A% = ClipVars%
        B% = BfVars%
        C% = BmVars%
        D% = PlotShape%
        X% = BmVars%+12 : REM x pos
        Y% = BmVars%+16 : REM y pos
        K% = BmVars%+20 : REM rgb565 colour
        Q% = BmVars%+24 : REM opacity (0 to 256)
        P% = PlotShapeBlend%
        BmVars%!0 = TrailDotBm.a%
        BmVars%!4 = TrailDotBm.w%
        BmVars%!8 = TrailDotBm.h%
        FOR I% = 0 TO MaxTrailDots%-1
          IF TrailDot{(I%)}.active% THEN
            !X% = TrailDot{(I%)}.x%
            !Y% = TrailDot{(I%)}.y%
            !K% = TrailDot{(I%)}.col%
            !Q% = TrailDot{(I%)}.opacity
            CALL P%
            TrailDot{(I%)}.opacity -= TrailDot{(I%)}.d * dt
            IF TrailDot{(I%)}.opacity <= 0 THEN
              TrailDot{(I%)}.active% = FALSE
            ENDIF
          ENDIF
        NEXT
  
        REM Update snake segment positions:
        FOR I% = segments%-1 TO 1 STEP -1
          dx = segX(I%-1) - segX(I%)
          dy = segY(I%-1) - segY(I%)
          l = SQR( dx^2 + dy^2 )
          dxn = dx / l
          dyn = dy / l
          d = segD(I%)
          segX(I%-1) = segX(I%) + d*dxn
          segY(I%-1) = segY(I%) + d*dyn
          IF d < segDist% THEN
            segD(I%) += 5.0 * dt
          ENDIF
        NEXT
  
        REM Handle our snake's tongue:
        IF tongue.active% THEN
          REM ARM version of sprite rotate+scale routine needs sign of angle flipped (bug ?)
          IF ARM% THEN
            S% = -1
          ELSE
            S% = 1
          ENDIF
          BmVars%!0 = TongueBm.a%
          BmVars%!4 = TongueBm.w%
          BmVars%!8 = TongueBm.h%
          A% = BfVars%
          B% = BmVars%
          C% = SinTbl%
          r = 24 - 40*ABSSIN(tongue.theta)
          BmVars%!12 = segX(segments%-1) - r*SIN(snake.angle)
          BmVars%!16 = segY(segments%-1) - r*COS(snake.angle)
          BmVars%!20 = S% * &10000 * DEG(snake.angle) MOD (&10000 * 360) : REM angle
          BmVars%!24 = &10000 * 0.3 : REM scale
          CALL PlotRotateScale%
          tongue.theta += tongue.dtheta * dt
          IF tongue.theta > PI THEN
            tongue.active% = FALSE
          ENDIF
        ELSE
          IF time% >= tongue.delay% THEN
            PROCPlaySoundEffect( SoundSample.hiss.p% )
            tongue.active% = TRUE
            tongue.delay% = time% + 1000 + 4000*RND(1)
            tongue.theta = 0
          ENDIF
        ENDIF
  
        REM Draw snake body segments (not the head):
        A% = ClipVars%
        B% = BfVars%
        C% = BmVars%
        X% = BmVars%+12
        Y% = BmVars%+16
        K% = BmVars%+20
        BmVars%!0  = SnakeBodyBm.a%
        BmVars%!4  = SnakeBodyBm.w%
        BmVars%!8  = SnakeBodyBm.w%
        M% = SQR(2 * (SnakeBodyBm.w%/2)^2)
        S% = SnakeBodyBm.w%/2
        P% = PlotShape%
        FOR I% = 0 TO segments%-2
          !X% = segX(I%) - S%
          !Y% = segY(I%) - S%
          !K% = ColTbl%(I% AND &F)
          CALL P%
          IF RND(50)=1 THEN
            J% = pointindex%
            a = 2*PI*RND(1)
            r = M%*RND(1)
            TrailDot{(J%)}.active% = TRUE
            TrailDot{(J%)}.x% = segX(I%) + r*SINa
            TrailDot{(J%)}.y% = segY(I%) + r*COSa
            TrailDot{(J%)}.col% = !K%
            TrailDot{(J%)}.opacity = 256
            TrailDot{(J%)}.d = 30 + 50*RND(1) : REM opacity decrement
            pointindex% += 1
            IF pointindex% = MaxTrailDots% THEN
              pointindex% = 0
            ENDIF
          ENDIF
        NEXT
  
        REM Fast colour-based head-body collision detection test:
        R% = SnakeHeadBm.w%/2
        A% = 0
        B% = BfVars%
        C% = segX(segments%-1) + R%*SIN(snake.angle)
        D% = segY(segments%-1) + R%*COS(snake.angle)
        K% = USR(ReadPixel%)
        IF K% <> bgCol% THEN
          P% = ^ColTbl%(0)
          FOR I% = P% TO P%+4*16-1 STEP 4
            IF K% = !I% THEN
              dead% = TRUE
            ENDIF
          NEXT
        ENDIF
  
        REM Draw the food and check for collisions with it:
        IF food.active% THEN
          PROCDrawFood
          PROCHandleSnakeFoodCollision
        ENDIF
  
        REM Draw the snake's head:
        A% = ClipVars%
        B% = BfVars%
        C% = BmVars%
        X% = BmVars%+12
        Y% = BmVars%+16
        BmVars%!0  = SnakeHeadBm.a%
        BmVars%!4  = SnakeHeadBm.w%
        BmVars%!8  = SnakeHeadBm.w%
        S% = SnakeHeadBm.w%/2
        !X% = segX(segments%-1) - S%
        !Y% = segY(segments%-1) - S%
        CALL Plot%
  
        REM Draw snake's eyes:
        BmVars%!0  = EyeBm.a%
        BmVars%!4  = EyeBm.w%
        BmVars%!8  = EyeBm.h%
        xx% = segX(segments%-1) - EyeBm.w%/2
        yy% = segY(segments%-1) - EyeBm.h%/2
        !X% = xx% + 16*SIN(snake.angle-0.5)
        !Y% = yy% + 16*COS(snake.angle-0.5)
        CALL Plot%
        !X% = xx% + 16*SIN(snake.angle+0.5)
        !Y% = yy% + 16*COS(snake.angle+0.5)
        CALL Plot%
  
        REM Create new food if food.new% flag is true, and time delay has expired:
        IF food.new% THEN
          IF food.delay% < time% THEN
            PROCNewFood
          ENDIF
        ENDIF
  
        dir% = 0 : REM 0 = no direction button pressed, 1 = anticlockwise, 2 = clockwise
  
        IF NOT BB4W% THEN
          PROCDrawCtrlButtons
          REM Check if arrow buttons have been clicked on/pressed:
          MOUSE msX%, msY%, msBtn%
          IF msBtn% <> 0 THEN
            msX% /= 2
            msY% /= 2
            REM check left direction (anticlockwise rotation) button:
            X% = AnticlockwiseArrowBm.w%/2
            Y% = (ScrH% DIV 3) + AnticlockwiseArrowBm.h%/2
            IF (msX% - X%)^2 + (msY% - Y%)^2 < 64^2 THEN
              dir% = 1
            ELSE
              REM check right direction (clockwise rotation) button:
              X% = ScrW% - ClockwiseArrowBm.w%/2
              Y% = (ScrH% DIV 3) + ClockwiseArrowBm.h%/2
              IF (msX% - X%)^2 + (msY% - Y%)^2 < 64^2 THEN
                dir% = 2
              ENDIF
            ENDIF
          ENDIF
        ENDIF
  
        REM Check left arrow key:
        IF INKEY-26 OR (dir% = 1) THEN
          snake.angle -= 1.25 * dt
        ENDIF
  
        REM Check right arrow key:
        IF INKEY-122 OR (dir% = 2) THEN
          snake.angle += 1.25 * dt
        ENDIF
  
        REM ==============================================================================================
        REM Check for collision of snake head with body segments:
        REM (REM'd out because I've switched to pixel colour-based collision detection for speed purposes)
        REM X% = segX(segments%-1)
        REM Y% = segY(segments%-1)
        REM D% = 16^2
        REM FOR I% = segments%-5 TO 0 STEP -1
        REM IF (X%-segX(I%))^2 + (Y%-segY(I%))^2 <= D% THEN
        REM dead% = TRUE
        REM ENDIF
        REM NEXT
        REM ==============================================================================================
  
        REM Game over if snake head breaches the boundaries:
        X% = segX(segments%-1)
        Y% = segY(segments%-1)
        IF X% < 0 OR X% >= ScrW% OR Y% < 0 OR Y% >= ScrH% THEN
          dead% = TRUE
        ENDIF
  
        segX(segments%-1) += snake.speed * SIN(snake.angle) * dt
        segY(segments%-1) += snake.speed * COS(snake.angle) * dt
  
        A% = BfVars%
        B% = BmVars%
        BmVars%!0 = SplashBm.a%
        BmVars%!4 = SplashBm.w%
        BmVars%!8 = SplashBm.h%
        W% = BmVars%+12
        H% = BmVars%+16
        X% = BmVars%+20
        Y% = BmVars%+24
        P% = PlotScale%
        FOR I% = 0 TO NumFoodExpParticles%-1
          IF FoodParticle{(I%)}.active% THEN
            PROCHandleFoodParticle
          ENDIF
        NEXT
  
        PROCPrintScore
        PROCPrintHiScore
        IF ShowFPS% PROCPrintFPS
  
        IF score% > HiScore% AND hiscorebeaten% = FALSE THEN
          PROCSaveHiScore( score% )
          welldone.active% = TRUE
          hiscorebeaten% = TRUE
          PROCPlaySoundEffect( SoundSample.ding.p% )
        ENDIF
  
        IF welldone.active% THEN
          scale = 0.1 + 0.9*SIN(welldone.theta)
          BmVars%!0 = WellDoneBm.a%
          BmVars%!4 = WellDoneBm.w%
          BmVars%!8 = WellDoneBm.h%
          BmVars%!12 = scale * WellDoneBm.w% : REM scaled width
          BmVars%!16 = scale * WellDoneBm.h% : REM scaled height
          BmVars%!20 = (ScrW% - (BmVars%!12))/2
          BmVars%!24 = 0.6*ScrH% - (BmVars%!16)/2
          BmVars%!28 = 255*SQRscale : REM opacity
          A% = bmp{}
          B% = BmVars%
          CALL PlotScaleBlend%
          IF welldone.theta <= PI/2 THEN
            welldone.theta += 0.9 * welldone.dtheta * dt
          ELSE
            welldone.theta += welldone.dtheta * dt
          ENDIF
          IF welldone.theta >= PI THEN
            welldone.active% = FALSE
          ENDIF
        ENDIF
  
        REM Display the canvas:
        OSCLI "MDISPLAY "+STR$~bmp%
  
        IF BB4W% THEN PROC`w : REM Wait for VSync
  
        *REFRESH
  
        frames% += 1
  
        REM Flush keyboard buffer every 100 frames:
        IF flushKbBuf% > 0 THEN
          flushKbBuf% -= 1
        ELSE
          *FX 21,0
          flushKbBuf% = 25
        ENDIF
  
        IF time% - time00% >= 1000 THEN
          frameRate% = frames%
          frames% = 0
          SYS GetTicks$ TO time00%
        ENDIF
  
        IF BB4W% IF INKEY-113 dead% = TRUE
  
      UNTIL dead%

      IF dead% THEN PROCDead

      ENDPROC

      DEF PROCDead
      LOCAL I%, J%, N%, T%, X%, Y%, Z%, a, r, s

      PROCSaveHiScore( score% )

      IF score% > HiScore% THEN HiScore% = score%

      FOR I% = 0 TO segments%-1
        X% = segX(I%)-4
        Y% = segY(I%)-4
        FOR J% = 1 TO 10
          a = 2*PI*RND(1)
          r = 2*RND(1)
          s = 5+10*RND(1)
          ExpParticleX(N%) = X% + r*SINa
          ExpParticleY(N%) = Y% + r*COSa
          ExpParticleXV(N%) = s*SINa
          ExpParticleYV(N%) = s*COSa
          ExpParticleCol%(N%) = ColTbl%(I% AND 15)
          N% += 1
        NEXT
      NEXT

      SYS GetTicks$ TO time0%
      T% = time0%+2500
      Z% = FALSE

      REPEAT
        SYS GetTicks$ TO time%
        dt = (time% - time0%) / 500
        time0% = time%
  
        REM Enter a CPU-friendly spin loop if window loses focus:
        IF NOT FNCheckForWindowFocus THEN
          SYS GetTicks$ TO time0%
          T% += (time0% - time%)
          *REFRESH OFF
        ENDIF
  
        REM Clear screen:
        A% = !BfVars% : B%=ScrH% : C% = &114F : CALL Clr%
  
        A% = ClipVars%
        B% = BfVars%
        C% = BmVars%
        BmVars%!0  = ParticleBm.a%
        BmVars%!4  = ParticleBm.w%
        BmVars%!8  = ParticleBm.h%
        X% = BmVars% + 12
        Y% = BmVars% + 16
        K% = BmVars% + 20
        P% = PlotShape%
        FOR I% = 0 TO N%-1
          !X% = ExpParticleX(I%)
          !Y% = ExpParticleY(I%)
          !K% = ExpParticleCol%(I%)
          CALL P%
          ExpParticleX(I%)+=ExpParticleXV(I%)*dt
          ExpParticleY(I%)+=ExpParticleYV(I%)*dt
        NEXT
  
        REM Display the canvas:
        OSCLI "MDISPLAY "+STR$~bmp%
  
        IF BB4W% THEN PROC`w : REM Wait for VSync
  
        *REFRESH
  
        IF NOT Z% THEN PROCPlaySoundEffect( SoundSample.pop.p% ) : Z% = TRUE
  
      UNTIL time% >= T%
      ENDPROC

      DEF PROCSaveHiScore( S% )
      LOCAL F%
      IF S% > HiScore% THEN
        REM HiScore% = S%
        F% = OPENOUT( HiScoreFile$ )
        PRINT#F%, S%
        CLOSE#F%
      ENDIF
      ENDPROC

      DEF PROCNewFood
      LOCAL I%, D%, V%, X%, Y%
      REPEAT
        V% = TRUE
        X% = 32 + RND(ScrW% - 64)
        Y% = 32 + RND(ScrH% - 64)
        FOR I% = 0 TO segments%-1
          IF I% < segments%-1 THEN
            D% = 50
          ELSE
            D% = 100
          ENDIF
          IF SQR( (X%-segX(I%))^2 + (Y%-segY(I%))^2 ) < D% THEN
            V% = FALSE
            EXIT FOR
          ENDIF
        NEXT
      UNTIL V%
      food.x%      = X%
      food.y%      = Y%
      food.new%    = FALSE
      food.active% = TRUE
      food.scale   = 1.0
      food.dscale  = 0.5
      food.ddscale = 1.5 : REM constant
      ENDPROC

      DEF PROCHandleSnakeFoodCollision
      LOCAL I%, J%, a, s, d
      d = (segX(segments%-1)-food.x%)^2 + (segY(segments%-1)-food.y%)^2
      IF d <= 24^2 THEN
        segX(segments%) = segX(segments%-1)
        segY(segments%) = segY(segments%-1)
        segD(segments%) = 0.1
        segX(segments%-1) = (segX(segments%-1) + segX(segments%-2)) / 2
        segY(segments%-1) = (segY(segments%-1) + segY(segments%-2)) / 2
        segments% += 1
        food.new% = TRUE
        food.delay% = time% + 1000
        food.active% = FALSE
        score% += 1
        PROCPlaySoundEffect( SoundSample.slurp.p% )
        I% = FoodParticleIndex%
        FOR J% = 1 TO 20+RND(10)
          a = 2*PI*RND(1)
          s = 20 + 30*RND(1)
          FoodParticle{(I%)}.active% = TRUE
          FoodParticle{(I%)}.x = food.x%
          FoodParticle{(I%)}.y = food.y%
          FoodParticle{(I%)}.dx = s * SINa
          FoodParticle{(I%)}.dy = s * COSa
          FoodParticle{(I%)}.scale = 0.125 + 0.5*RND(1)
          FoodParticle{(I%)}.dscale = 0.1 + 0.5*RND(1)
          I% += 1
          IF I% = NumFoodExpParticles% THEN
            I% = 0
          ENDIF
        NEXT
        FoodParticleIndex% = I%
      ENDIF
      ENDPROC

      DEF PROCHandleFoodParticle
      S% = 32 * FoodParticle{(I%)}.scale
      !W% = S%
      !H% = S%
      !X% = FoodParticle{(I%)}.x - 0.5*S%
      !Y% = FoodParticle{(I%)}.y - 0.5*S%
      CALL P%
      FoodParticle{(I%)}.x += FoodParticle{(I%)}.dx * dt
      FoodParticle{(I%)}.y += FoodParticle{(I%)}.dy * dt
      FoodParticle{(I%)}.scale -= FoodParticle{(I%)}.dscale * dt
      IF FoodParticle{(I%)}.scale < 0.1 THEN
        FoodParticle{(I%)}.active% = FALSE
      ENDIF
      ENDPROC

      REM Draw clockwise & anticlockwise control buttons:
      DEF PROCDrawCtrlButtons
      LOCAL A%, B%, C%, D%
      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      D% = Plot%
      BmVars%!0  = AnticlockwiseArrowBm.a%
      BmVars%!4  = AnticlockwiseArrowBm.w%
      BmVars%!8  = AnticlockwiseArrowBm.h%
      BmVars%!12 = 0
      BmVars%!16 = ScrH% DIV 3
      BmVars%!20 = 1 : REM opacity (ignored, but must be != 0)
      CALL PlotAvg%
      BmVars%!0  = ClockwiseArrowBm.a%
      BmVars%!4  = ClockwiseArrowBm.w%
      BmVars%!8  = ClockwiseArrowBm.h%
      BmVars%!12 = ScrW% - ClockwiseArrowBm.w%
      BmVars%!16 = ScrH% DIV 3
      BmVars%!20 = 1 : REM opacity (ignored, but must be != 0)
      CALL PlotAvg%
      ENDPROC

      REM Print/draw score:
      DEF PROCPrintScore
      LOCAL A%, B%, C%, I%, X%, s$
      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      BmVars%!0 = ScoreBm.a%
      BmVars%!4 = ScoreBm.w%
      BmVars%!8 = ScoreBm.h%
      BmVars%!12 = 0
      BmVars%!16 = ScrH%-ScoreBm.h%
      CALL Plot%
      BmVars%!4 = 20 : REM bitmap width
      BmVars%!8 = 27 : REM bitmap height
      BmVars%!16 = ScrH%-27-15 : REM Y pos
      s$ = STR$score%
      REM X% = ScrW% - 20*LENs$ - 8
      X% = 8
      FOR I% = 1 TO LENs$
        BmVars%!12 = X% + 20*(I%-1)
        !BmVars% = ScoreDigitBm%(VALMID$(s$,I%,1))
        CALL Plot%
      NEXT
      ENDPROC

      DEF PROCPrintHiScore
      LOCAL A%, B%, C%, I%, L%, X%, s$
      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      BmVars%!0 = HiScoreBm.a%
      BmVars%!4 = HiScoreBm.w%
      BmVars%!8 = HiScoreBm.h%
      BmVars%!12 = ScrW%-HiScoreBm.w%
      BmVars%!16 = ScrH%-HiScoreBm.h%
      CALL Plot%
      BmVars%!4 = 20 : REM bitmap width
      BmVars%!8 = 27 : REM bitmap height
      BmVars%!16 = ScrH%-27-15 : REM Y pos
      s$ = STR$HiScore%
      L% = LENs$
      X% = ScrW% - 20*L% - 8
      FOR I% = 1 TO L%
        BmVars%!12 = X% + 20*(I%-1)
        !BmVars% = ScoreDigitBm%(VALMID$(s$,I%,1))
        CALL Plot%
      NEXT
      ENDPROC

      REM Print/draw frame rate:
      DEF PROCPrintFPS
      LOCAL A%, B%, C%, L%, I%, i%, s$
      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      BmVars%!4 = 12 : REM bitmap width
      BmVars%!8 = 20 : REM bitmap height
      s$ = STR$frameRate%
      BmVars%!16 = 8 : REM bitmap Y pos
      L% = LENs$
      X% = ScrW%-12*L%-6
      FOR I% = 1 TO L%
        i% = ASCMID$(s$, I%, 1) - 48
        BmVars%!12 = X% + 12*(I%-1)
        !BmVars% = ScoreDigits12x20% + ScoreDigits12x20%!(4*i%)
        CALL Plot%
      NEXT
      ENDPROC

      DEF PROCDrawFood
      LOCAL A%, B%, C%

      REM Draw the underlaying expanding food sprite (opacity inversely proportional to scale):
      IF food.scale < 3 THEN
        BmVars%!0 = StrawbBm.a%
        BmVars%!4 = StrawbBm.w%
        BmVars%!8 = StrawbBm.h%
        BmVars%!12 = food.scale * StrawbBm.w% : REM scaled width
        BmVars%!16 = food.scale * StrawbBm.h% : REM scaled height
        BmVars%!20 = food.x% - (BmVars%!12)/2
        BmVars%!24 = food.y% - (BmVars%!16)/2
        BmVars%!28 = 255 * (1 - food.scale/3)
        A% = bmp{}
        B% = BmVars%
        CALL PlotScaleBlend%
        food.scale += food.dscale * dt
        food.dscale += food.ddscale * dt
      ENDIF

      REM Draw the overlaying non-scaled food sprite:
      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      BmVars%!0  = StrawbBm.a%
      BmVars%!4  = StrawbBm.w%
      BmVars%!8  = StrawbBm.h%
      BmVars%!12 = food.x% - StrawbBm.w%/2
      BmVars%!16 = food.y% - StrawbBm.h%/2
      CALL Plot%
      ENDPROC

      DEF PROCResetSnake
      LOCAL I%, T%
      SYS GetTicks$ TO T%
      score% = 0
      food.new% = TRUE
      food.delay% = T% + 2000
      food.active% = FALSE
      snake.x = ScrW% / 2
      snake.y = ScrH% / 4
      snake.angle = 0.0
      snake.speed = 60.0
      segments% = 10
      FOR I% = 0 TO segments%-1
        segX(I%) = snake.x + 2.0*(segments%-I%+1)*segDist%
        segY(I%) = snake.y - (segments%-I%+1)*segDist%
        segD(I%) = segDist%
      NEXT I%
      FoodParticleIndex% = 0
      FOR I% = 0 TO NumFoodExpParticles%-1
        FoodParticle{(I%)}.active% = FALSE
      NEXT I%
      ENDPROC

      DEF PROCStartScreen
      LOCAL A%, B%, C%, D%, F%, I%, X%, Y%
      LOCAL x%, y%
      LOCAL msX%, msY%, msBtn%
      LOCAL go%, exit%

      *REFRESH OFF

      X% = ScrW% / 2
      Y% = ScrH% / 5
      A% = !BfVars%
      B% = ScrH%
      C% = &114F
      CALL Clr%
      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      BmVars%!0 = StartScreenBm.a%
      BmVars%!4 = StartScreenBm.w%
      BmVars%!8 = StartScreenBm.h%
      BmVars%!12 = 0 : REM X co-ord
      BmVars%!16 = (ScrH% - StartScreenBm.h%) / 2 : REM Y co-ord
      CALL BPlot%
      BmVars%!0 = StartButtonBm.a%
      BmVars%!4 = StartButtonBm.w%
      BmVars%!8 = StartButtonBm.h%
      BmVars%!12 = X% - StartButtonBm.w%/2 : REM X co-ord
      BmVars%!16 = Y% - StartButtonBm.h%/2 : REM Y co-ord
      CALL Plot%

      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      BmVars%!0 = CanYouBeatBm.a%
      BmVars%!4 = CanYouBeatBm.w%
      BmVars%!8 = CanYouBeatBm.h%
      BmVars%!12 = (ScrW% - CanYouBeatBm.w%)/2      - 2
      BmVars%!16 = (ScrH% - CanYouBeatBm.h%)/2 + 16 - 2
      BmVars%!20 = 0
      CALL PlotShape%
      BmVars%!12 = (ScrW% - CanYouBeatBm.w%)/2
      BmVars%!16 = (ScrH% - CanYouBeatBm.h%)/2 + 16
      CALL Plot%

      IF BB4W% THEN
        A% = ClipVars%
        B% = BfVars%
        C% = BmVars%
        BmVars%!0 = InfoBm.a%
        BmVars%!4 = InfoBm.w%
        BmVars%!8 = InfoBm.h%
        BmVars%!12 = (ScrW% - InfoBm.w%)/2
        BmVars%!16 = 8
        CALL Plot%
      ENDIF

      BmVars%!4 = 26
      BmVars%!8 = 37
      BmVars%!20 = 0
      s$ = STR$HiScore%
      X% = (ScrW% - (26+4)*LENs$) / 2
      FOR I% = 0 TO LENs$-1
        BmVars%!0 = BigScoreDigitBm%(VALMID$(s$,I%+1,1))
  
        x% = X% + (26+4)*I%
        y% = (ScrH% - CanYouBeatBm.h%)/2 - 37 - 4
  
        BmVars%!12 = x%-2
        BmVars%!16 = y%-2
        CALL PlotShape%
  
        BmVars%!12 = x%
        BmVars%!16 = y%
        CALL Plot%
  
      NEXT

      OSCLI "MDISPLAY "+STR$~bmp%
      *REFRESH

      go% = FALSE
      exit% = FALSE
      *FX 21,0
      X% = ScrW% / 2
      Y% = ScrH% / 5

      *REFRESH ON

      REPEAT
        REM Enter a CPU-friendly spin loop if window loses focus:
        F% = FNCheckForWindowFocus
  
        MOUSE msX%, msY%, msBtn%
        msX% /= 2
        msY% /= 2
        IF msBtn% = 4 THEN
          IF SQR((msX% - X%)^2 + (msY% - Y%)^2) <= 36 THEN
            go% = TRUE
            PROCPlaySoundEffect( SoundSample.click.p% )
          ENDIF
        ENDIF
        REM IF INKEY-113 THEN exit% = TRUE
        IF BB4W% AND INKEY-99 THEN go% = TRUE
        WAIT 2
      UNTIL go%

      REM IF exit% THEN
      REM IF NOT BB4W% THEN
      REM CHAIN @lib$+"../examples/tools/touchide"
      REM ENDIF
      REM ENDIF
      ENDPROC

      DEF PROCShowSplashScreen(T%)
      LOCAL A%, B%, C%
      REM LOCAL bmpfile$
      REM bmpfile$ = @dir$ + "splash_360x480.bmp"
      A% = !BfVars%
      B% = ScrH%
      C% = &114F
      CALL Clr%
      REM OSCLI "DISPLAY """+bmpfile$+""" "+STR$0+","+STR$(ScrH%-480)+","+STR$(2*360)+","+STR$(2*480)
      A% = ClipVars%
      B% = BfVars%
      C% = BmVars%
      D% = Plot%
      BmVars%!0 = SplashScreenBm.a%
      BmVars%!4 = SplashScreenBm.w%
      BmVars%!8 = SplashScreenBm.h%
      BmVars%!12 = 0 : REM X co-ord
      BmVars%!16 = (ScrH% - SplashScreenBm.h%) / 2 : REM Y co-ord
      CALL BPlot%
      OSCLI "MDISPLAY "+STR$~bmp%
      *REFRESH
      WAIT T%
      ENDPROC

      DEF PROCShowBlankScreen(T%)
      LOCAL A%, B%, C%
      A% = !BfVars%
      B% = ScrH%
      C% = &114F
      CALL Clr%
      OSCLI "MDISPLAY "+STR$~bmp%
      *REFRESH
      WAIT T%
      ENDPROC

      DEF FNread_data( r$ )
      LOCAL I%, data%, byte%, s$
      data% = FNmalloc( 32768 )
      RESTORE
      REPEAT : READ s$ : UNTIL s$ = r$
      I% = 0
      REPEAT
        READ byte%
        IF byte% <> -1 THEN
          data%?I% = byte%
          I% += 1
        ENDIF
      UNTIL byte% = -1
      = data%

      DEF FNCheckForWindowFocus
      REM Return TRUE if window has input focus when first checked (i.e. no spin/wait loop entered)
      REM Return FALSE if window didn't have input focus (and therefore entered a spin loop until it did gain focus)
      LOCAL F%
      F% = TRUE
      IF BB4W% THEN
        SYS "GetForegroundWindow" TO R%
        IF R% <> @hwnd% THEN
          *REFRESH ON
          REPEAT
            SYS "GetForegroundWindow" TO R%
            WAIT 2
          UNTIL R% = @hwnd%
          F% = FALSE
        ENDIF
      ELSE
        REM SDL_WINDOW_INPUT_FOCUS = 0x00000200,        /**< window has input focus */
        REM SDL_WINDOW_MOUSE_FOCUS = 0x00000400,        /**< window has mouse focus */
        SYS "SDL_GetWindowFlags", @hwnd% TO R%
        IF (R% AND &200) = 0 THEN
          *REFRESH ON
          REPEAT
            SYS "SDL_GetWindowFlags", @hwnd% TO R%
            WAIT 2
          UNTIL R% AND &200
          F% = FALSE
        ENDIF
      ENDIF
      = F%

      DEF FNLoadData( f$ )
      LOCAL A%, F%, S%
      F% = OPENIN( f$ )
      IF F% = 0 THEN CLOSE#F% : VDU 7 : PRINT '" Can't load " + f$ : PRINT '"" : WAIT 300
      S% = EXT#F%
      CLOSE#F%
      DIM A% S%+15
      A% = (A% + 7) AND -8
      OSCLI "LOAD """ + f$ + """ " + STR$~A%
      = A%

      DEF FNCreateBMP_RGB565(W%, H%)
      LOCAL A%, S%
      S% = 70 + 2*W%*H%
      DIM A% S%+15
      A% = ((A% + 7) AND -8) + 2
      A%?0 = ASC"B"
      A%?1 = ASC"M"
      A%!2 = S%
      A%!10 = 70
      A%!14 = 56
      A%!18 = W%
      A%!22 = H%
      A%?26 = 1
      A%?28 = 16
      A%!30 = 3
      A%!34 = 2*W%*H%
      A%!38 = 11808
      A%!42 = 11808
      A%!54 = &0000F800
      A%!58 = &000007E0
      A%!62 = &0000001F
      = A%

      DEF PROCLoadBMP24( file$, RETURN bmp{} )
      LOCAL bmp24%
      DIM bmp{a%, w%, h%}
      bmp24% = FNLoadData( file$ )
      bmp.w% = bmp24%!18
      bmp.h% = bmp24%!22
      bmp.a% = FNmalloc( 4 * bmp.w% * bmp.h% )
      IF SGN(bmp.h%) = -1 THEN bmp.h% *= -1
      A% = bmp24%
      B% = bmp.a%
      CALL ConvBMP24% : REM Convert 24-bpp (RGB888) BMP bitmap to raw 32-bpp (RGB8888) bitmap
      A% = bmp.a%
      B% = bmp.a%
      C% = bmp.w%
      D% = bmp.h%
      CALL ConvBmRGB565% : REM Convert raw 32-bpp bitmap to 16-bpp RGB565
      ENDPROC

      DEF PROCConvBMP24( addr%, RETURN bmp{} )
      LOCAL bmp24%
      DIM bmp{a%, w%, h%}
      bmp24% = addr% : REM address of 24-bpp (RGB888) BMP bitmap
      bmp.w% = bmp24%!18
      bmp.h% = bmp24%!22
      bmp.a% = FNmalloc( 4 * bmp.w% * bmp.h% )
      IF SGN(bmp.h%) = -1 THEN bmp.h% *= -1
      A% = bmp24%
      B% = bmp.a%
      CALL ConvBMP24% : REM Convert 24-bpp (RGB888) BMP bitmap to raw 32-bpp (RGB8888) bitmap
      A% = bmp.a%
      B% = bmp.a%
      C% = bmp.w%
      D% = bmp.h%
      CALL ConvBmRGB565% : REM Convert raw 32-bpp bitmap to 16-bpp RGB565
      ENDPROC

      DEF FNGetDataAddr( D%, name$ )
      LOCAL I%, s$
      REPEAT
        s$ = $$(D% + 40*I%)
        I% += 1
      UNTIL s$ = "*" OR s$ = name$
      IF s$ = "*" THEN ERROR 0, "FNGetDataAddr: Can't find " + name$
      = D% + D%!(40*(I%-1) + 36)

      DEF FNGetDataChunkSize( D%, name$ )
      LOCAL I%, s$
      REPEAT
        s$ = $$(D% + 40*I%)
        I% += 1
      UNTIL s$ = "*" OR s$ = name$
      IF s$ = "*" THEN ERROR 0, "FNGetDataChunkSize: Can't find " + name$
      = D%!(40*(I%-1) + 32)

      DEF FNBuildSineTable
      LOCAL I%, SinTbl%, SinTblSz%, SinTblRange%, SinTblBase%, SinTblMid%
      LOCAL SinTblFP%, SinTblFPM%, SinTblFPM2%, SinTblDivs%
      LOCAL k
      SinTblFP%   = 16
      SinTblFPM%  = 2^SinTblFP%
      SinTblFPM2% = (2^SinTblFP%) >> 1
      SinTblDivs% = 16
      k            = 1/SinTblDivs%
      SinTblRange% = 450
      SinTblSz%    = 4*2*(SinTblRange%+1)*SinTblDivs%
      SinTblMid%   = SinTblDivs%*(SinTblRange% - 90)
      DIM SinTblBase% SinTblSz%+3 : SinTblBase%=(SinTblBase%+3) AND -4
      SinTbl%      = SinTblBase% + 4*SinTblMid%
      FOR I% = 0 TO SinTblSz%-1
        SinTblBase%!(4*I%)=SinTblFPM%*SINRAD(k*I%)
      NEXT I%
      = SinTbl%

      REM A BB4W-specific subroutine that waits for the vertical refresh.
      REM The BB4W-specific routine (PROC`7), which uses DirectDraw 7, must have been called (once) first.
      DEFPROC`w:PRIVATEB%,G%,I%,S%,W%:LOCALL%,P%,T%:IFS%=0 S%=FNGetProcAddress("Sleep")
      IFB%=0SYS"timeBeginPeriod",1:B%=1
      IFI%=0PROC`7(I%,G%)
      L%=0:P%=^T%:REPEAT:L%=T%:SYSS%,1:SYSG%,I%,P%:UNTILT%<L%:ENDPROC

      REM A BB4W-specific routine that sets up a DirectDraw 7 interface.
      DEFPROC`7(RETURN I%,RETURN G%):LOCALD%,E%,J%,K%,L%
      SYS"LoadLibrary","DDRAW.DLL"TOD%:IFD%=0 ERROR100,"`7 failed"
      SYS"GetProcAddress",D%,"DirectDrawCreateEx"TOE%:DIMJ%19,L%95:J%=J%+3AND-4
      L%=L%+3AND-4:!J%=&15E65EC0:J%!4=&11D23B9C:J%!8=&60002FB9:J%!12=&5BEA9797
      SYSE%,0,^K%,J%,0:L%=!K%:I%=K%:G%=L%!64
      ENDPROC

      DEF PROCFixWindowSize
      IF BB4W% THEN
        REM GWL_STYLE = -16
        REM WS_THICKFRAME = &40000
        REM WS_MAXIMIZEBOX = &10000
        REM SYS "GetWindowLong", @hwnd%, GWL_STYLE TO ws%
        REM SYS "SetWindowLong", @hwnd%, GWL_STYLE, ws% AND NOT WS_THICKFRAME \
        REM \ AND NOT WS_MAXIMIZEBOX
        LOCAL W%
        SYS "GetWindowLong", @hwnd%, -16 TO W%
        SYS "SetWindowLong", @hwnd%, -16, W% AND NOT &40000 AND NOT &10000
      ELSE
        REM If BBCSDL (Windows, Linux, or--very unlikely--MacOS) then prevent window resize:
        IF (@platform% AND &F) < 3 THEN
          SYS "SDL_SetWindowResizable", @hwnd%, 0
        ENDIF
      ENDIF
      ENDPROC

      DEF FNmalloc( N% )
      LOCAL A%
      DIM A% N%+15
      A% = (A% + 7) AND -8
      = A%

      DEF PROCerror( s$ )
      LOCAL F%
      OSCLI "REFRESH ON"
      F% = OPENIN(@lib$+"../examples/tools/touchide") : CLOSE#F%
      IF NOT BB4W% THEN
        IF ERR = 17 THEN
          OSCLI "font"
          IF F% THEN CHAIN @lib$+"../examples/tools/touchide"
        ENDIF
      ENDIF
      CLS : OFF : VDU 7
      COLOUR 9  : PRINT '" *** ERROR ***" : WAIT 100
      COLOUR 11 : PRINT '" " + s$; : WAIT 250
      COLOUR 7  : PRINT '''" Closing in 5 seconds...";
      WAIT 500
      IF NOT BB4W% THEN
        OSCLI "font"
        IF F% THEN CHAIN @lib$+"../examples/tools/touchide"
      ENDIF
      OSCLI "font"
      QUIT
      ENDPROC

      REM BB4W's compiler considers 'equd' a variable name, hence...
      REM!Keep equd
      REM The following function (FNGetProcAddress) is the work of RTR
      DEF FNGetProcAddress(p$)
      LOCAL P% : DIM P% LOCAL 8
      [OPT 0:nop:]
      CASE P%?-1 OF
        WHEN &90: [OPT 0:call p$:] = P% + P%!-4
        WHEN &E1: [OPT 0:equd p$:] = P%!-4
      ENDCASE
      = FALSE

      REM The following function (FNLoadSound) is the work of RTR (hereby acknowledged)
      REM *** NOT USED IN THIS PROGRAM ***
      DEF FNLoadSound(path$)
      LOCAL A%, P%, R%
      DIM P% 7 : REM allocate from heap
      SYS "SDL_RWFromFile", path$, "rb" TO R%
      IF R% = 0 ERROR 114, "Couldn't open sound file: " + path$
      SYS `SDL_LoadWAV_RW`, R%, 1, AudioSpec{}, P%, P%+4 TO A%
      IF A% = FALSE ERROR 115, "Couldn't buffer sound: " + path$
      SYS "memcmp", A%, AudioSpec{}, 9 TO R%
      IF R% ERROR 116, "Couldn't convert sound format: " + path$
      = P%

      REM The following function (FNLoadSoundFromMem) is based on the work of RTR
      DEF FNLoadSoundFromMem(D%, S%) : REM D% = WAV data address, S% = WAV size (in bytes)
      IF BB4W% THEN =D% : REM As simple as that!
      LOCAL A%, P%, R%
      DIM P% 7 : REM allocate from heap
      SYS "SDL_RWFromMem", D%, S% TO R%
      IF R% = 0 ERROR 118, "Couldn't open WAV file from memory address"
      SYS `SDL_LoadWAV_RW`, R%, 1, AudioSpec{}, P%, P%+4 TO A%
      IF A% = FALSE ERROR 119, "Couldn't buffer sound"
      SYS "memcmp", A%, AudioSpec{}, 9 TO R%
      IF R% ERROR 120, "Couldn't convert sound format"
      = P%

      REM The following function (PROCPlaySoundEffect) is based on the work of RTR
      REM In 'native' SDL 2.0 we can play only one sound at a time (and no music).
      REM Playing multiple sounds and MP3 music would maen linking with SDL2_mixer.
      DEF PROCPlaySoundEffect(P%)
      IF NOT SoundFX% ENDPROC
      IF BB4W% THEN SYS "PlaySound", P%, 0, 5 : ENDPROC
      LOCAL temp{} : DIM temp{} = AudioSpec{}
      IF @hwo% = FALSE SYS "SDL_OpenAudioDevice", FALSE, FALSE, AudioSpec{}, temp{}, 0, @memhdc% TO @hwo%
      IF @hwo% = FALSE ERROR 117, "Couldn't open audio device"
      SYS `SDL_ClearQueuedAudio`, @hwo%, @memhdc%
      SYS `SDL_QueueAudio`, @hwo%, !P%, P%!4, @memhdc%
      SYS `SDL_PauseAudioDevice`, @hwo%, FALSE, @memhdc%
      ENDPROC

      REM Look at this clever function:
      DEF FNCrunched
      ON ERROR LOCAL =TRUE
      LOCAL varname%, V%
      varname% = 123456789
      V% = EVAL("varname%") : REM This should induce a trappable error if program is crunched
      =FALSE

      DATA "clipbitmap_x86"
      DATA 96,199,64,28,255,255,255,255,139,120,20,59,120,4,15,141,192,0,0,0,139,112,24,59,112,8,15,141,180,0,0,0,139,72,12,139,80,16,131,249,0,125,3,247,217,144,131,250
      DATA 0,125,3,247,218,144,247,217,59,249,15,142,148,0,0,0,247,218,59,242,15,142,138,0,0,0,247,217,247,218,199,64,28,0,0,0,0,199,64,32,0,0,0,0,199,64,36,0
      DATA 0,0,0,199,64,40,0,0,0,0,137,72,44,137,80,48,137,120,52,137,112,56,139,239,3,233,59,104,4,126,13,43,104,4,41,104,44,199,64,32,255,255,255,255,131,255,0,125
      DATA 20,41,120,40,1,120,44,199,64,52,0,0,0,0,199,64,32,255,255,255,255,139,238,3,234,59,104,8,126,13,43,104,8,41,104,48,199,64,32,255,255,255,255,131,254,0,125,20
      DATA 41,112,36,1,112,48,199,64,56,0,0,0,0,199,64,32,255,255,255,255,97,195
      DATA -1

      DATA "clr16_360x640_x86"
      DATA 96,139,248,139,195,37,255,255,0,0,139,216,193,227,16,11,195,185,0,194,1,0,252,243,171,97,195
      DATA -1

      DATA "clr16_360xh_x86"
      DATA 96,139,211,139,248,139,193,37,255,255,0,0,139,216,193,227,16,11,195,185,104,1,0,0,15,175,202,209,233,252,243,171,97,195
      DATA -1

      DATA "bplot16_x86"
      DATA 96,131,236,32,139,83,4,139,123,8,137,80,4,137,120,8,139,81,4,139,121,8,137,80,12,137,120,16,139,81,12,139,121,16,137,80,20,137,120,24,255,16,247,64,28,255,255,255
      DATA 255,15,133,70,0,0,0,139,27,139,9,139,120,4,137,60,36,209,36,36,15,175,120,56,3,120,52,209,231,3,251,139,112,12,137,116,36,4,209,100,36,4,15,175,112,36,3,112
      DATA 40,209,230,3,241,139,104,48,87,86,139,72,44,252,243,102,165,94,95,3,60,36,3,116,36,4,77,117,235,131,196,32,97,195
      DATA -1

      DATA "plot16_x86"
      DATA 96,131,236,32,139,83,4,139,123,8,137,80,4,137,120,8,139,81,4,139,121,8,137,80,12,137,120,16,139,81,12,139,121,16,137,80,20,137,120,24,255,16,247,64,28,255,255,255
      DATA 255,15,133,83,0,0,0,139,27,139,9,139,120,4,137,60,36,209,36,36,15,175,120,56,3,120,52,209,231,3,251,139,112,12,137,116,36,4,209,100,36,4,15,175,112,36,3,112
      DATA 40,209,230,3,241,139,80,44,139,104,48,51,201,102,139,4,78,102,169,255,255,116,4,102,137,4,79,65,59,202,124,237,3,60,36,3,116,36,4,77,117,225,131,196,32,97,195
      DATA -1

      DATA "plot16_avg_x86"
      DATA 96,131,236,32,131,121,20,0,15,142,202,0,0,0,129,121,20,0,1,0,0,124,8,255,210,144,233,185,0,0,0,139,83,4,139,123,8,137,80,4,137,120,8,139,81,4,139,121
      DATA 8,137,80,12,137,120,16,139,81,12,139,121,16,137,80,20,137,120,24,255,16,247,64,28,255,255,255,255,15,133,134,0,0,0,139,81,20,137,84,36,16,139,27,139,9,139,120,4
      DATA 137,60,36,209,36,36,15,175,120,56,3,120,52,209,231,3,251,139,112,12,137,116,36,4,209,100,36,4,15,175,112,36,3,112,40,209,230,3,241,139,80,44,137,84,36,8,139,80
      DATA 48,137,84,36,12,185,33,8,0,0,247,209,51,237,102,247,4,110,255,255,116,22,15,183,4,111,15,183,28,110,35,193,35,217,209,232,209,235,3,195,102,137,4,111,69,59,108,36
      DATA 8,15,140,215,255,255,255,3,60,36,3,116,36,4,255,76,36,12,15,133,196,255,255,255,131,196,32,97,195
      DATA -1

      DATA "plot16_shape_x86"
      DATA 96,131,236,32,139,115,4,139,123,8,137,112,4,137,120,8,139,113,4,139,121,8,137,112,12,137,120,16,139,113,12,139,121,16,137,112,20,137,120,24,255,16,247,64,28,255,255,255
      DATA 255,15,133,90,0,0,0,139,81,20,129,226,255,255,0,0,139,27,139,9,139,120,4,137,60,36,209,36,36,15,175,120,56,3,120,52,209,231,3,251,139,112,12,137,116,36,4,209
      DATA 100,36,4,15,175,112,36,3,112,40,209,230,3,241,139,88,44,139,104,48,51,201,102,247,4,78,255,255,116,4,102,137,20,79,65,59,203,124,239,3,60,36,3,116,36,4,77,117
      DATA 227,131,196,32,97,195
      DATA -1

      DATA "plot16_shapeblend_x86"
      DATA 96,131,236,32,131,121,24,0,15,142,37,1,0,0,129,121,24,0,1,0,0,124,8,255,210,144,233,20,1,0,0,139,83,4,139,123,8,137,80,4,137,120,8,139,81,4,139,121
      DATA 8,137,80,12,137,120,16,139,81,12,139,121,16,137,80,20,137,120,24,255,16,247,64,28,255,255,255,255,15,133,225,0,0,0,139,81,20,137,84,36,20,139,81,24,137,84,36,16
      DATA 139,27,139,9,139,120,4,137,60,36,209,36,36,15,175,120,56,3,120,52,209,231,3,251,139,112,12,137,116,36,4,209,100,36,4,15,175,112,36,3,112,40,209,230,3,241,139,80
      DATA 44,137,84,36,8,139,80,48,137,84,36,12,51,237,102,247,4,110,255,255,116,113,15,183,4,111,139,92,36,20,85,51,237,139,200,139,211,131,225,31,131,226,31,43,209,15,175,84
      DATA 36,20,193,234,8,3,202,11,233,139,200,139,211,129,225,224,7,0,0,129,226,224,7,0,0,193,233,5,193,234,5,43,209,15,175,84,36,20,193,234,8,3,202,193,225,5,11,233
      DATA 37,0,248,0,0,129,227,0,248,0,0,193,232,11,193,235,11,43,216,15,175,92,36,20,193,235,8,3,195,193,224,11,11,197,93,102,137,4,111,69,59,108,36,8,15,140,124,255
      DATA 255,255,3,60,36,3,116,36,4,255,76,36,12,15,133,105,255,255,255,131,196,32,97,195
      DATA -1

      DATA "plot16_scale_x86"
      DATA 96,139,236,131,237,64,129,236,128,0,0,0,137,69,36,139,51,137,117,40,139,115,4,137,117,44,139,115,8,137,117,48,139,115,12,137,117,52,139,115,16,137,117,56,139,115,20,137
      DATA 117,60,139,115,24,137,117,64,155,219,227,155,217,60,36,102,139,4,36,102,37,255,243,102,13,0,12,102,137,4,36,217,44,36,139,85,52,131,250,0,15,142,68,1,0,0,139,125
      DATA 56,131,255,0,15,142,56,1,0,0,104,0,0,1,0,219,4,36,219,69,44,218,117,52,216,201,219,92,36,4,219,69,48,218,117,56,222,201,219,92,36,8,131,196,4,139,69,36
      DATA 139,93,60,247,218,59,218,15,142,5,1,0,0,59,88,4,15,141,252,0,0,0,139,77,64,247,223,59,207,15,142,239,0,0,0,59,72,8,15,141,230,0,0,0,247,218,247,223
      DATA 137,92,36,8,137,76,36,12,137,84,36,16,137,124,36,20,199,68,36,24,0,0,0,0,199,68,36,28,0,0,0,0,139,112,4,209,230,137,116,36,32,131,251,0,125,16,199,68
      DATA 36,8,0,0,0,0,1,92,36,16,41,92,36,28,139,80,4,43,85,52,59,218,126,11,139,112,4,43,116,36,8,137,116,36,16,131,249,0,125,16,199,68,36,12,0,0,0,0
      DATA 1,76,36,20,41,76,36,24,139,80,8,43,85,56,59,202,126,11,139,112,8,43,116,36,12,137,116,36,20,139,116,36,12,15,175,112,4,3,116,36,8,209,230,3,48,139,93,40
      DATA 51,255,139,207,3,76,36,24,15,175,76,36,4,193,233,16,15,175,77,44,209,225,87,80,85,83,139,68,36,16,139,108,36,44,3,217,139,124,36,32,79,139,215,3,213,15,175,208
      DATA 193,234,16,102,139,20,83,102,133,210,116,4,102,137,20,126,79,125,230,91,93,88,95,3,116,36,32,71,59,124,36,20,124,176,129,196,128,0,0,0,97,195
      DATA -1

      DATA "plot16_scaleblend_x86"
      DATA 96,139,236,131,237,72,129,236,128,0,0,0,137,69,36,139,51,137,117,40,139,115,4,137,117,44,139,115,8,137,117,48,139,115,12,137,117,52,139,115,16,137,117,56,139,115,20,137
      DATA 117,60,139,115,24,137,117,64,139,115,28,137,117,68,131,125,68,0,15,142,253,1,0,0,129,125,68,0,1,0,0,15,142,7,0,0,0,199,69,68,0,1,0,0,155,219,227,155
      DATA 217,60,36,102,139,4,36,102,37,255,243,102,13,0,12,102,137,4,36,217,44,36,139,85,52,131,250,0,15,142,195,1,0,0,139,125,56,131,255,0,15,142,183,1,0,0,104,0
      DATA 0,1,0,219,4,36,219,69,44,218,117,52,216,201,219,92,36,4,219,69,48,218,117,56,222,201,219,92,36,8,131,196,4,139,69,36,139,93,60,247,218,59,218,15,142,132,1,0
      DATA 0,59,88,4,15,141,123,1,0,0,139,77,64,247,223,59,207,15,142,110,1,0,0,59,72,8,15,141,101,1,0,0,247,218,247,223,137,92,36,8,137,76,36,12,137,84,36,16
      DATA 137,124,36,20,199,68,36,24,0,0,0,0,199,68,36,28,0,0,0,0,139,112,4,209,230,137,116,36,32,139,117,68,137,116,36,36,131,251,0,125,16,199,68,36,8,0,0,0
      DATA 0,1,92,36,16,41,92,36,28,139,80,4,43,85,52,59,218,126,11,139,112,4,43,116,36,8,137,116,36,16,131,249,0,125,16,199,68,36,12,0,0,0,0,1,76,36,20,41
      DATA 76,36,24,139,80,8,43,85,56,59,202,126,11,139,112,8,43,116,36,12,137,116,36,20,139,116,36,12,15,175,112,4,3,116,36,8,209,230,3,48,139,93,40,51,255,139,207,3
      DATA 76,36,24,15,175,76,36,4,193,233,16,15,175,77,44,209,225,87,80,85,83,81,139,68,36,20,139,108,36,48,3,217,139,124,36,36,79,139,215,3,213,15,175,208,193,234,16,15
      DATA 183,20,83,102,133,210,116,114,15,183,12,126,80,83,85,51,237,139,233,139,218,131,229,31,131,227,31,43,221,15,175,92,36,68,193,235,8,3,235,139,193,139,218,37,224,7,0,0
      DATA 129,227,224,7,0,0,193,232,5,193,235,5,43,216,15,175,92,36,68,193,235,8,3,195,193,224,5,11,232,139,193,139,218,37,0,248,0,0,129,227,0,248,0,0,193,232,11,193
      DATA 235,11,43,216,15,175,92,36,68,193,235,8,3,195,193,224,11,11,232,102,137,44,126,93,91,88,79,15,141,116,255,255,255,89,91,93,88,95,3,116,36,32,71,59,124,36,20,15
      DATA 140,56,255,255,255,129,196,128,0,0,0,97,195
      DATA -1

      DATA "plot16_rotatescale_x86"
      DATA 96,139,236,131,237,40,129,236,0,2,0,0,155,219,227,137,69,36,139,51,137,117,40,139,115,4,137,117,44,139,115,8,137,117,48,139,115,12,137,117,52,139,115,16,137,117,56,139
      DATA 115,20,137,117,60,139,115,24,137,117,64,139,216,139,11,137,76,36,32,139,75,4,137,76,36,36,139,83,8,137,84,36,40,209,225,137,76,36,44,139,77,44,137,76,36,48,139,77
      DATA 44,209,233,137,76,36,52,139,77,48,209,233,137,76,36,56,104,70,223,145,63,104,57,157,82,162,104,0,0,1,0,221,68,36,4,219,69,60,218,52,36,222,201,131,196,12,221,92
      DATA 36,60,104,0,0,1,0,219,69,64,218,52,36,131,196,4,221,84,36,68,219,68,36,56,217,193,219,68,36,52,222,201,219,92,36,76,222,201,219,92,36,80,139,76,36,76,139,93
      DATA 52,137,92,36,100,41,76,36,100,137,92,36,104,1,76,36,104,137,92,36,108,1,76,36,108,137,92,36,112,41,76,36,112,139,76,36,80,139,93,56,137,92,36,116,1,76,36,116
      DATA 137,92,36,120,1,76,36,120,137,92,36,124,41,76,36,124,137,156,36,128,0,0,0,41,140,36,128,0,0,0,199,132,36,132,0,0,0,0,0,0,0,199,132,36,136,0,0,0
      DATA 0,0,0,0,199,132,36,140,0,0,0,0,0,0,0,199,132,36,144,0,0,0,0,0,0,0,199,132,36,148,0,0,0,0,0,0,0,199,132,36,152,0,0,0,0,0,0,0
      DATA 199,132,36,156,0,0,0,0,0,0,0,199,132,36,160,0,0,0,0,0,0,0,139,244,141,190,136,0,0,0,87,141,190,132,0,0,0,87,141,126,60,87,255,118,116,255,118,100
      DATA 255,117,56,255,117,52,232,184,4,0,0,141,190,144,0,0,0,87,141,190,140,0,0,0,87,141,126,60,87,255,118,120,255,118,104,255,117,56,255,117,52,232,149,4,0,0,141,190
      DATA 152,0,0,0,87,141,190,148,0,0,0,87,141,126,60,87,255,118,124,255,118,108,255,117,56,255,117,52,232,114,4,0,0,141,190,160,0,0,0,87,141,190,156,0,0,0,87,141
      DATA 126,60,87,255,182,128,0,0,0,255,118,112,255,117,56,255,117,52,232,76,4,0,0,199,132,36,164,0,0,0,64,66,15,0,199,132,36,168,0,0,0,192,189,240,255,199,132,36
      DATA 172,0,0,0,64,66,15,0,199,132,36,176,0,0,0,192,189,240,255,141,190,164,0,0,0,87,255,182,132,0,0,0,232,103,4,0,0,141,190,168,0,0,0,87,255,182,132,0
      DATA 0,0,232,106,4,0,0,141,190,164,0,0,0,87,255,182,140,0,0,0,232,67,4,0,0,141,190,168,0,0,0,87,255,182,140,0,0,0,232,70,4,0,0,141,190,164,0,0
      DATA 0,87,255,182,148,0,0,0,232,31,4,0,0,141,190,168,0,0,0,87,255,182,148,0,0,0,232,34,4,0,0,141,190,164,0,0,0,87,255,182,156,0,0,0,232,251,3,0
      DATA 0,141,190,168,0,0,0,87,255,182,156,0,0,0,232,254,3,0,0,141,190,172,0,0,0,87,255,182,136,0,0,0,232,215,3,0,0,141,190,176,0,0,0,87,255,182,136,0
      DATA 0,0,232,218,3,0,0,141,190,172,0,0,0,87,255,182,144,0,0,0,232,179,3,0,0,141,190,176,0,0,0,87,255,182,144,0,0,0,232,182,3,0,0,141,190,172,0,0
      DATA 0,87,255,182,152,0,0,0,232,143,3,0,0,141,190,176,0,0,0,87,255,182,152,0,0,0,232,146,3,0,0,141,190,172,0,0,0,87,255,182,160,0,0,0,232,107,3,0
      DATA 0,141,190,176,0,0,0,87,255,182,160,0,0,0,232,110,3,0,0,139,132,36,164,0,0,0,139,156,36,168,0,0,0,139,140,36,172,0,0,0,139,148,36,176,0,0,0,137
      DATA 132,36,180,0,0,0,137,156,36,184,0,0,0,137,140,36,188,0,0,0,137,148,36,192,0,0,0,59,68,36,36,15,141,182,2,0,0,59,195,15,132,174,2,0,0,59,76,36
      DATA 40,15,141,164,2,0,0,59,202,15,132,156,2,0,0,131,248,0,125,11,199,132,36,180,0,0,0,0,0,0,0,59,92,36,36,124,12,139,124,36,36,79,137,188,36,184,0,0
      DATA 0,131,249,0,125,11,199,132,36,188,0,0,0,0,0,0,0,59,84,36,40,124,12,139,124,36,40,79,137,188,36,192,0,0,0,221,68,36,68,217,232,222,241,221,148,36,196,0
      DATA 0,0,221,68,36,60,106,255,219,4,36,131,196,4,222,201,217,193,217,193,217,254,222,201,221,156,36,204,0,0,0,217,255,222,201,221,148,36,212,0,0,0,221,156,36,220,0,0
      DATA 0,106,255,219,4,36,131,196,4,221,132,36,204,0,0,0,222,201,221,156,36,228,0,0,0,139,93,52,43,156,36,180,0,0,0,137,156,36,236,0,0,0,139,93,56,43,156,36
      DATA 188,0,0,0,137,156,36,240,0,0,0,219,132,36,240,0,0,0,221,132,36,204,0,0,0,222,201,219,132,36,236,0,0,0,221,132,36,212,0,0,0,222,201,219,68,36,52,222
      DATA 225,222,225,221,156,36,244,0,0,0,219,132,36,240,0,0,0,221,132,36,220,0,0,0,222,201,219,132,36,236,0,0,0,221,132,36,228,0,0,0,222,201,219,68,36,56,222,225
      DATA 222,225,221,156,36,252,0,0,0,221,132,36,244,0,0,0,221,156,36,4,1,0,0,221,132,36,252,0,0,0,221,156,36,12,1,0,0,104,0,0,1,0,219,4,36,131,196,4
      DATA 221,132,36,204,0,0,0,221,132,36,212,0,0,0,221,132,36,220,0,0,0,221,132,36,228,0,0,0,216,204,219,156,36,20,1,0,0,216,203,219,156,36,24,1,0,0,216,202
      DATA 219,156,36,28,1,0,0,216,201,219,156,36,32,1,0,0,221,132,36,4,1,0,0,221,132,36,12,1,0,0,216,202,219,156,36,40,1,0,0,222,201,219,156,36,36,1,0,0
      DATA 139,93,44,193,227,16,139,77,48,193,225,16,137,156,36,44,1,0,0,137,140,36,48,1,0,0,139,156,36,180,0,0,0,209,227,137,156,36,52,1,0,0,139,132,36,24,1,0
      DATA 0,137,4,36,139,132,36,20,1,0,0,137,68,36,4,139,132,36,48,1,0,0,137,68,36,8,139,132,36,184,0,0,0,137,68,36,12,139,125,40,139,180,36,188,0,0,0,139
      DATA 92,36,48,85,139,172,36,48,1,0,0,139,140,36,40,1,0,0,139,148,36,44,1,0,0,139,68,36,48,15,175,198,3,68,36,36,3,132,36,56,1,0,0,86,139,180,36,188
      DATA 0,0,0,59,205,115,36,59,84,36,16,115,30,81,82,193,249,16,193,250,16,15,175,211,3,202,15,183,20,79,247,194,255,255,0,0,116,3,102,137,16,90,89,131,192,2,3,76
      DATA 36,8,3,84,36,12,131,198,1,59,116,36,20,126,196,94,139,140,36,36,1,0,0,139,148,36,32,1,0,0,1,140,36,40,1,0,0,1,148,36,44,1,0,0,70,59,180,36
      DATA 196,0,0,0,15,142,113,255,255,255,93,129,196,0,2,0,0,97,195,96,139,236,131,236,16,139,125,44,43,125,36,139,117,48,43,117,40,137,60,36,137,116,36,4,139,69,52,139
      DATA 93,56,139,77,60,221,0,217,192,217,254,217,201,217,255,217,192,217,194,218,76,36,4,217,201,218,12,36,222,193,218,69,36,219,27,218,76,36,4,217,201,218,12,36,217,224,222,193
      DATA 218,69,40,219,25,131,196,16,97,194,28,0,96,139,68,36,36,139,92,36,40,139,11,59,193,125,2,137,3,97,194,8,0,96,139,68,36,36,139,92,36,40,139,11,59,193,126,2
      DATA 137,3,97,194,8,0
      DATA -1

      DATA "readpixel16_x86"
      DATA 96,51,192,139,59,139,115,4,139,107,8,59,206,115,15,59,213,115,11,15,175,214,3,209,209,226,102,139,4,23,137,68,36,28,97,195
      DATA -1

      DATA "convbmrgb8888torgb565_x86"
      DATA 96,139,248,139,243,15,175,209,51,237,15,182,4,175,15,182,92,175,1,15,182,76,175,2,105,192,31,31,0,0,105,219,63,63,0,0,105,201,31,31,0,0,193,232,16,131,208,0
      DATA 193,235,16,131,211,0,193,233,16,131,209,0,193,227,5,193,225,11,11,195,11,193,102,137,4,110,69,59,234,124,187,97,195
      DATA -1

      DATA "convpxlrgb8888torgb565_x86"
      DATA 96,131,236,4,137,4,36,15,182,4,36,15,182,92,36,1,15,182,76,36,2,105,192,31,31,0,0,105,219,63,63,0,0,105,201,31,31,0,0,193,232,16,131,208,0,193,235,16
      DATA 131,211,0,193,233,16,131,209,0,193,227,5,193,225,11,11,195,11,193,131,196,4,137,68,36,28,97,195
      DATA -1

      DATA "convbmp24torgb8888_x86"
      DATA 96,131,236,16,128,56,66,117,109,128,120,1,77,117,103,131,120,10,54,117,97,128,120,28,24,117,91,139,104,18,107,237,3,137,44,36,139,112,18,131,230,3,139,44,36,3,238,137
      DATA 108,36,4,139,104,22,131,253,0,125,2,247,221,137,108,36,8,139,248,131,199,54,139,235,51,210,51,201,138,4,15,138,100,15,1,138,92,15,2,136,69,0,136,101,1,136,93,2
      DATA 131,193,3,131,197,4,59,12,36,124,225,3,124,36,4,66,59,84,36,8,124,212,131,196,16,97,195
      DATA -1

      REM *********************************************************************************************************************

      DATA "clipbitmap_arm"
      DATA 255,95,45,233,0,192,224,227,28,192,128,229,4,176,128,226,126,0,155,232,1,0,85,225,255,159,189,168,2,0,86,225,255,159,189,168,3,0,117,225,255,159,189,216,4,0,118,225
      DATA 255,159,189,216,148,208,143,229,148,224,143,229,0,208,160,227,0,224,224,227,28,208,128,229,32,208,128,229,0,112,160,227,0,128,160,227,3,144,160,225,4,160,160,225,3,176,133,224
      DATA 1,0,91,225,1,176,75,192,11,144,73,192,32,224,128,197,0,0,85,227,5,128,72,176,5,144,137,176,0,80,160,179,32,224,128,181,4,176,134,224,2,0,91,225,2,176,75,192
      DATA 11,160,74,192,32,224,128,197,0,0,86,227,6,112,71,176,6,160,138,176,0,96,160,179,32,224,128,181,36,112,128,229,40,128,128,229,44,144,128,229,48,160,128,229,52,80,128,229
      DATA 56,96,128,229,4,208,159,229,4,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0
      DATA -1

      DATA "clr16_360x640_arm"
      DATA 255,95,45,233,144,208,143,229,144,224,143,229,1,24,160,225,33,24,160,225,1,24,129,225,1,32,160,225,2,48,160,225,2,64,160,225,2,80,160,225,2,96,160,225,2,112,160,225
      DATA 2,128,160,225,2,144,160,225,2,160,160,225,2,176,160,225,2,192,160,225,2,208,160,225,2,224,160,225,10,29,160,227,252,127,160,232,252,127,160,232,252,127,160,232,252,127,160,232
      DATA 252,127,160,232,252,127,160,232,252,127,160,232,252,127,160,232,252,127,160,232,252,127,160,232,252,127,160,232,252,127,160,232,252,127,160,232,252,31,160,232,1,16,81,226,239,255,255,26
      DATA 4,208,159,229,4,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0
      DATA -1

      DATA "clr16_360xh_arm"
      DATA 255,95,45,233,140,208,143,229,140,224,143,229,2,40,160,225,34,40,160,225,2,40,130,225,2,48,160,225,2,64,160,225,2,80,160,225,2,96,160,225,2,112,160,225,2,128,160,225
      DATA 2,144,160,225,2,160,160,225,2,176,160,225,2,192,160,225,2,208,160,225,2,224,160,225,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232
      DATA 248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,248,127,160,232,1,16,81,226,238,255,255,26,4,208,159,229
      DATA 4,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0
      DATA -1

      DATA "bplot16_arm"
      DATA 255,95,45,233,4,64,145,229,8,80,145,229,4,96,146,229,8,112,146,229,12,128,146,229,16,144,146,229,4,64,128,229,8,80,128,229,12,96,128,229,16,112,128,229,20,128,128,229
      DATA 24,144,128,229,0,192,144,229,60,255,47,225,28,192,144,229,0,0,92,227,255,159,189,24,0,16,145,229,0,32,146,229,36,80,144,229,40,112,144,229,44,128,144,229,48,144,144,229
      DATA 52,160,144,229,56,176,144,229,72,208,143,229,72,224,143,229,155,164,42,224,138,16,129,224,149,118,39,224,135,32,130,224,0,48,160,227,131,192,160,225,188,80,146,225,188,80,129,225
      DATA 1,48,131,226,8,0,83,225,249,255,255,186,134,32,130,224,132,16,129,224,1,144,89,226,244,255,255,26,4,208,159,229,4,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0
      DATA -1

      DATA "plot16_arm"
      DATA 255,95,45,233,4,64,145,229,8,80,145,229,4,96,146,229,8,112,146,229,12,128,146,229,16,144,146,229,4,64,128,229,8,80,128,229,12,96,128,229,16,112,128,229,20,128,128,229
      DATA 24,144,128,229,0,192,144,229,60,255,47,225,28,192,144,229,0,0,92,227,255,159,189,24,0,16,145,229,0,32,146,229,36,80,144,229,40,112,144,229,44,128,144,229,48,144,144,229
      DATA 52,160,144,229,56,176,144,229,80,208,143,229,80,224,143,229,155,164,42,224,138,16,129,224,149,118,39,224,135,32,130,224,255,192,160,227,12,196,140,225,0,48,160,227,179,80,146,225
      DATA 12,0,21,225,179,80,129,17,2,48,131,226,136,0,83,225,249,255,255,186,134,32,130,224,132,16,129,224,1,144,89,226,244,255,255,26,4,208,159,229,4,224,159,229,255,159,189,232
      DATA 0,0,0,0,0,0,0,0
      DATA -1

      DATA "plot16_avg_arm"
      DATA 255,95,45,233,4,64,145,229,8,80,145,229,4,96,146,229,8,112,146,229,12,128,146,229,16,144,146,229,4,64,128,229,8,80,128,229,12,96,128,229,16,112,128,229,20,128,128,229
      DATA 24,144,128,229,0,192,144,229,60,255,47,225,28,192,144,229,0,0,92,227,255,159,189,24,0,16,145,229,0,32,146,229,36,80,144,229,40,112,144,229,44,128,144,229,48,144,144,229
      DATA 52,160,144,229,56,176,144,229,100,208,143,229,100,224,143,229,155,164,42,224,138,16,129,224,149,118,39,224,135,32,130,224,2,203,160,227,33,192,140,226,0,48,160,227,179,112,145,225
      DATA 179,80,146,225,5,0,21,225,12,112,199,17,12,80,197,17,167,112,160,17,165,80,135,16,179,80,129,17,2,48,131,226,136,0,83,225,244,255,255,186,134,32,130,224,132,16,129,224
      DATA 1,144,89,226,239,255,255,26,4,208,159,229,4,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0
      DATA -1

      DATA "plot16_shape_arm"
      DATA 255,95,45,233,4,64,145,229,8,80,145,229,4,96,146,229,8,112,146,229,12,128,146,229,16,144,146,229,4,64,128,229,8,80,128,229,12,96,128,229,16,112,128,229,20,128,128,229
      DATA 24,144,128,229,0,192,144,229,60,255,47,225,28,192,144,229,0,0,92,227,255,159,189,24,0,144,224,227,20,160,146,229,41,168,10,224,120,160,143,229,0,16,145,229,0,32,146,229
      DATA 36,80,144,229,40,112,144,229,44,128,144,229,48,144,144,229,52,160,144,229,56,176,144,229,88,208,143,229,88,224,143,229,155,164,42,224,138,16,129,224,149,118,39,224,135,32,130,224
      DATA 60,160,159,229,255,192,160,227,12,196,140,225,0,48,160,227,179,80,146,225,12,0,21,225,179,160,129,17,2,48,131,226,136,0,83,225,249,255,255,186,134,32,130,224,132,16,129,224
      DATA 1,144,89,226,244,255,255,26,8,208,159,229,8,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0,0,0,0,0
      DATA -1

      DATA "plot16_shapeblend_arm"
      DATA 255,95,45,233,24,192,146,229,0,0,92,227,255,159,189,216,0,176,160,227,1,12,92,227,1,176,160,163,51,255,47,161,1,0,91,227,255,159,189,8,4,64,145,229,8,80,145,229
      DATA 4,96,146,229,8,112,146,229,12,128,146,229,16,144,146,229,4,64,128,229,8,80,128,229,12,96,128,229,16,112,128,229,20,128,128,229,24,144,128,229,0,192,144,229,60,255,47,225
      DATA 28,192,144,229,0,0,92,227,255,159,189,24,20,160,146,229,224,160,143,229,212,208,143,229,212,224,143,229,24,224,146,229,0,16,145,229,0,32,146,229,36,80,144,229,40,112,144,229
      DATA 44,128,144,229,48,144,144,229,52,160,144,229,56,176,144,229,155,164,42,224,138,16,129,224,149,118,39,224,135,32,130,224,255,192,160,227,12,196,140,225,152,80,159,229,0,48,160,227
      DATA 179,160,146,225,12,0,26,225,22,0,0,10,179,0,145,225,31,160,0,226,31,176,5,226,10,208,75,224,158,13,13,224,45,116,138,224,126,174,0,226,126,190,5,226,170,162,160,225
      DATA 171,178,160,225,10,208,75,224,158,13,13,224,45,212,138,224,141,114,135,225,62,171,0,226,62,187,5,226,170,165,160,225,171,181,160,225,10,208,75,224,158,13,13,224,45,212,138,224
      DATA 141,117,135,225,179,112,129,17,2,48,131,226,136,0,83,225,226,255,255,186,134,32,130,224,132,16,129,224,1,144,89,226,221,255,255,26,4,208,159,229,4,224,159,229,255,159,189,232
      DATA 0,0,0,0,0,0,0,0,0,0,0,0
      DATA -1

      DATA "plot16_scale_arm"
      DATA 255,95,45,233,1,192,160,225,254,0,156,232,0,28,144,232,192,0,143,226,6,12,128,226,0,28,128,232,172,214,143,229,172,230,143,229,1,0,84,227,165,1,0,186,1,0,85,227
      DATA 163,1,0,186,4,128,144,229,6,144,160,225,4,160,134,224,8,0,89,225,158,1,0,170,0,144,160,35,8,0,90,225,8,160,160,161,1,160,74,162,0,0,90,227,152,1,0,186
      DATA 8,176,144,229,7,192,160,225,5,208,135,224,11,0,92,225,147,1,0,170,0,192,160,35,11,0,93,225,11,208,160,161,1,208,77,162,0,0,93,227,141,1,0,186,16,16,128,229
      DATA 20,32,128,229,24,48,128,229,28,64,128,229,32,80,128,229,36,96,128,229,40,112,128,229,48,144,128,229,52,160,128,229,56,192,128,229,60,208,128,229,0,16,160,227,2,224,160,225
      DATA 0,64,100,226,174,31,176,225,0,224,110,18,14,24,145,224,46,232,160,225,14,224,148,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224
      DATA 4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,160,177,224,0,160,106,50,0,160,106,226,0,64,100,226,138,160,160,225,3,224,160,225,0,80,101,226,174,31,176,225
      DATA 0,224,110,18,14,24,145,224,46,232,160,225,14,224,149,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224
      DATA 142,224,181,224,5,224,78,48,1,208,177,224,0,208,109,50,0,208,109,226,0,80,101,226,141,208,160,225,4,128,134,224,9,128,72,224,1,128,136,226,5,176,135,224,12,176,75,224
      DATA 1,176,139,226,154,8,8,224,157,11,11,224,0,128,104,226,0,176,107,226,2,136,152,224,0,128,160,179,72,128,128,229,3,184,155,224,0,176,160,179,76,176,128,229,60,224,144,229
      DATA 12,224,78,224,1,224,142,226,64,224,128,229,52,224,144,229,9,224,78,224,1,224,142,226,68,224,128,229,2,104,160,225,3,120,160,225,1,224,78,226,154,142,46,224,6,0,94,225
      DATA 105,0,0,186,2,80,160,225,1,224,132,226,0,224,110,226,165,31,176,225,0,80,101,18,5,24,145,224,37,88,160,225,5,80,158,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,160,177,224,0,160,106,50,0,160,106,226,138,160,160,225,16,16,144,229
      DATA 0,224,144,229,137,224,142,224,0,80,160,227,76,176,128,229,7,0,91,225,30,0,0,170,72,128,144,229,43,184,160,225,146,11,11,224,139,176,160,225,80,176,128,229,11,16,129,224
      DATA 4,176,144,229,56,192,144,229,5,192,140,224,155,12,12,224,140,192,142,224,68,64,144,229,1,64,68,226,40,184,160,225,139,176,160,225,187,176,145,225,11,0,27,225,176,176,204,17
      DATA 10,128,136,224,2,192,140,226,1,64,84,226,246,255,255,170,80,176,144,229,11,16,65,224,76,176,144,229,13,176,139,224,1,80,133,226,64,128,144,229,1,128,72,226,8,0,85,225
      DATA 221,255,255,218,4,208,159,229,4,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0
      DATA -1

      DATA "plot16_scaleblend_arm"
      DATA 255,95,45,233,1,192,160,225,254,1,156,232,0,0,88,227,255,159,189,216,1,12,88,227,1,140,160,195,0,28,144,232,96,0,143,226,7,12,128,226,0,28,128,232,68,215,143,229
      DATA 68,231,143,229,1,0,84,227,200,1,0,186,1,0,85,227,198,1,0,186,44,128,128,229,4,128,144,229,6,144,160,225,4,160,134,224,8,0,89,225,192,1,0,170,0,144,160,35
      DATA 8,0,90,225,8,160,160,161,1,160,74,162,0,0,90,227,186,1,0,186,8,176,144,229,7,192,160,225,5,208,135,224,11,0,92,225,181,1,0,170,0,192,160,35,11,0,93,225
      DATA 11,208,160,161,1,208,77,162,0,0,93,227,175,1,0,186,16,16,128,229,20,32,128,229,24,48,128,229,28,64,128,229,32,80,128,229,36,96,128,229,40,112,128,229,48,144,128,229
      DATA 52,160,128,229,56,192,128,229,60,208,128,229,0,16,160,227,2,224,160,225,0,64,100,226,174,31,176,225,0,224,110,18,14,24,145,224,46,232,160,225,14,224,148,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48
      DATA 1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,16,177,224,142,224,180,224,4,224,78,48,1,160,177,224,0,160,106,50,0,160,106,226
      DATA 0,64,100,226,138,160,160,225,3,224,160,225,0,80,101,226,174,31,176,225,0,224,110,18,14,24,145,224,46,232,160,225,14,224,149,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224
      DATA 5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,16,177,224,142,224,181,224,5,224,78,48,1,208,177,224,0,208,109,50,0,208,109,226,0,80,101,226,141,208,160,225
      DATA 4,128,134,224,9,128,72,224,1,128,136,226,5,176,135,224,12,176,75,224,1,176,139,226,154,8,8,224,157,11,11,224,0,128,104,226,0,176,107,226,2,136,152,224,0,128,160,179
      DATA 72,128,128,229,3,184,155,224,0,176,160,179,76,176,128,229,60,224,144,229,12,224,78,224,1,224,142,226,64,224,128,229,52,224,144,229,9,224,78,224,1,224,142,226,68,224,128,229
      DATA 2,104,160,225,3,120,160,225,88,112,128,229,1,224,78,226,154,142,46,224,6,0,94,225,105,0,0,186,2,80,160,225,1,224,132,226,0,224,110,226,165,31,176,225,0,80,101,18
      DATA 5,24,145,224,37,88,160,225,5,80,158,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224,14,80,69,48,1,16,177,224,133,80,190,224
      DATA 14,80,69,48,1,160,177,224,0,160,106,50,0,160,106,226,138,160,160,225,16,16,144,229,0,224,144,229,137,224,142,224,44,144,144,229,0,80,160,227,76,176,128,229,88,112,144,229
      DATA 7,0,91,225,61,0,0,170,72,128,144,229,43,184,160,225,146,11,11,224,139,176,160,225,80,176,128,229,11,16,129,224,4,176,144,229,56,192,144,229,5,192,140,224,155,12,12,224
      DATA 140,192,142,224,68,64,144,229,1,64,68,226,220,208,143,229,220,224,143,229,63,208,160,227,31,224,160,227,40,184,160,225,139,176,160,225,187,176,145,225,11,0,27,225,24,0,0,10
      DATA 164,64,143,229,164,80,143,229,164,128,143,229,176,48,220,225,31,64,3,226,31,80,11,226,4,80,69,224,153,5,5,224,37,132,132,224,163,66,13,224,171,82,13,224,4,80,69,224
      DATA 153,5,5,224,37,68,132,224,132,130,136,225,163,69,14,224,171,85,14,224,4,80,69,224,153,5,5,224,37,68,132,224,132,133,136,225,176,128,204,225,76,64,159,229,76,80,159,229
      DATA 76,128,159,229,10,128,136,224,2,192,140,226,1,64,84,226,221,255,255,170,68,208,159,229,68,224,159,229,80,176,144,229,11,16,65,224,76,176,144,229,13,176,139,224,1,80,133,226
      DATA 64,128,144,229,1,128,72,226,8,0,85,225,189,255,255,218,16,208,159,229,16,224,159,229,255,159,189,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA -1

      DATA "plot16_rotatescale_arm"
      DATA 255,95,45,233,180,192,143,226,6,204,140,226,112,0,144,232,112,0,140,232,16,176,140,226,240,7,145,232,240,7,139,232,52,38,143,229,4,16,156,229,129,16,160,225,72,16,140,229
      DATA 20,16,156,229,76,16,140,229,20,48,156,229,24,64,156,229,163,80,160,225,164,96,160,225,80,80,140,229,84,96,140,229,40,176,156,229,155,5,5,224,37,88,160,225,155,6,6,224
      DATA 38,104,160,225,28,0,156,229,32,16,156,229,1,118,160,227,1,134,224,227,1,150,160,227,1,166,224,227,36,64,156,229,5,32,64,224,6,48,129,224,121,1,0,235,128,32,140,229
      DATA 132,48,140,229,7,0,82,225,2,112,160,177,8,0,82,225,2,128,160,193,9,0,83,225,3,144,160,177,10,0,83,225,3,160,160,193,5,32,128,224,6,48,129,224,108,1,0,235
      DATA 136,32,140,229,140,48,140,229,7,0,82,225,2,112,160,177,8,0,82,225,2,128,160,193,9,0,83,225,3,144,160,177,10,0,83,225,3,160,160,193,5,32,128,224,6,48,65,224
      DATA 95,1,0,235,144,32,140,229,148,48,140,229,7,0,82,225,2,112,160,177,8,0,82,225,2,128,160,193,9,0,83,225,3,144,160,177,10,0,83,225,3,160,160,193,5,32,64,224
      DATA 6,48,65,224,82,1,0,235,152,32,140,229,156,48,140,229,7,0,82,225,2,112,160,177,8,0,82,225,2,128,160,193,9,0,83,225,3,144,160,177,10,0,83,225,3,160,160,193
      DATA 4,16,156,229,8,32,156,229,1,0,87,225,60,1,0,170,8,0,87,225,58,1,0,10,2,0,89,225,56,1,0,170,10,0,89,225,54,1,0,10,0,0,87,227,0,112,160,179
      DATA 1,0,88,225,1,128,160,161,1,128,72,162,0,0,89,227,0,144,160,179,2,0,90,225,2,160,160,161,1,160,74,162,160,112,140,229,164,128,140,229,168,144,140,229,172,160,140,229
      DATA 28,16,156,229,32,32,156,229,7,16,65,224,9,32,66,224,176,16,140,229,180,32,140,229,140,20,159,229,140,36,159,229,140,52,159,229,40,64,156,229,36,80,156,229,69,86,160,225
      DATA 2,96,133,224,5,81,145,231,6,97,145,231,0,64,100,226,165,15,176,225,0,80,101,18,5,8,144,224,37,88,160,225,5,80,148,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224
      DATA 4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,0,176,224,133,80,180,224,4,80,69,48,0,80,176,224,0,80,101,50,166,15,176,225,0,96,102,18,6,8,144,224
      DATA 38,104,160,225,6,96,148,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48,0,0,176,224,134,96,180,224,4,96,70,48
      DATA 0,96,176,224,0,96,102,50,0,80,101,226,0,96,102,226,133,80,160,225,134,96,160,225,6,112,160,225,5,128,160,225,0,128,104,226,204,112,140,229,208,128,140,229,212,80,140,229
      DATA 216,96,140,229,176,144,156,229,180,160,156,229,80,0,156,229,0,8,160,225,153,6,1,224,154,5,2,224,1,48,64,224,2,48,67,224,84,0,156,229,0,8,160,225,153,8,1,224
      DATA 154,7,2,224,1,64,64,224,2,64,68,224,196,48,140,229,200,64,140,229,20,16,156,229,24,32,156,229,1,24,160,225,2,40,160,225,16,144,156,229,76,160,156,229,200,208,143,229
      DATA 200,224,143,229,168,64,156,229,184,64,143,229,196,80,156,229,200,96,156,229,0,0,156,229,72,112,156,229,148,7,32,224,160,48,156,229,131,0,128,224,164,128,156,229,204,64,156,229
      DATA 208,224,156,229,1,0,85,225,8,0,0,42,2,0,86,225,6,0,0,42,69,184,160,225,70,216,160,225,157,186,43,224,139,176,160,225,187,208,153,225,13,0,29,225,176,208,192,17
      DATA 1,48,131,226,2,0,128,226,4,80,133,224,14,96,134,224,8,0,83,225,238,255,255,218,72,64,159,229,196,80,156,229,200,96,156,229,212,176,156,229,216,208,156,229,11,80,133,224
      DATA 13,96,134,224,196,80,140,229,200,96,140,229,1,64,132,226,172,128,156,229,8,0,84,225,214,255,255,218,24,208,159,229,24,224,159,229,255,159,189,232,14,240,160,225,0,0,0,0
      DATA 160,5,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,71,45,233,0,80,66,224,1,96,67,224,68,70,160,225,48,112,31,229,4,129,151,231,52,144,31,229
      DATA 9,64,132,224,4,113,151,231,60,64,31,229,149,7,9,224,150,72,42,224,10,144,137,224,73,40,128,224,150,71,41,224,149,8,10,224,10,144,73,224,73,56,129,224,243,135,189,232
      DATA 1,48,131,226,8,0,83,225,238,255,255,218,72,64,159,229,212,176,156,229,216,208,156,229,196,80,156,229,200,96,156,229,11,80,133,224,13,96,134,224,196,80,140,229,200,96,140,229
      DATA 1,64,132,226,172,128,156,229,8,0,84,225,214,255,255,218,24,208,159,229,24,224,159,229,255,159,189,232,14,240,160,225,0,0,0,0,160,5,0,0,0,128,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,243,71,45,233,0,80,66,224,1,96,67,224,68,70,160,225,48,112,31,229,4,129,151,231,52,144,31,229,9,64,132,224,4,113,151,231,60,64,31,229
      DATA 149,7,9,224,150,72,42,224,10,144,137,224,73,40,128,224,150,71,41,224,149,8,10,224,10,144,73,224,73,56,129,224,243,135,189,232,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA -1

      DATA "readpixel16_arm"
      DATA 254,64,45,233,0,0,160,227,0,64,145,229,4,80,145,229,8,96,145,229,5,0,82,225,254,128,189,40,6,0,83,225,254,128,189,40,147,5,7,224,2,112,135,224,135,112,160,225
      DATA 183,0,148,225,254,128,189,232
      DATA -1

      DATA "convbmrgb8888torgb565_arm"
      DATA 255,95,45,233,147,2,2,224,0,48,160,227,255,160,160,227,84,176,159,229,84,192,159,229,3,81,144,231,37,104,10,224,37,116,10,224,5,128,10,224,155,6,6,224,156,7,7,224
      DATA 155,8,8,224,38,104,176,225,0,96,166,226,39,120,176,225,0,112,167,226,40,136,176,225,0,128,168,226,135,130,136,225,134,133,136,225,131,64,160,225,180,128,129,225,1,48,131,226
      DATA 2,0,83,225,235,255,255,186,255,159,189,232,31,31,0,0,63,63,0,0
      DATA -1

      DATA "convpxlrgb8888torgb565_arm"
      DATA 126,64,45,233,255,16,160,227,32,40,1,224,32,52,1,224,0,64,1,224,48,80,159,229,48,96,159,229,149,2,2,224,150,3,3,224,149,4,4,224,34,40,176,225,0,32,162,226
      DATA 35,56,176,225,0,48,163,226,36,72,176,225,0,64,164,226,131,66,132,225,130,5,132,225,126,128,189,232,31,31,0,0,63,63,0,0
      DATA -1

      DATA "convbmp24torgb8888_arm"
      DATA 255,95,45,233,0,192,208,229,66,0,92,227,255,159,189,24,1,192,208,229,77,0,92,227,255,159,189,24,10,160,128,226,0,192,218,229,1,176,218,229,11,196,140,225,2,176,218,229
      DATA 11,200,140,225,3,176,218,229,11,204,140,225,54,0,92,227,255,159,189,24,28,192,208,229,24,0,92,227,255,159,189,24,18,160,128,226,0,32,218,229,1,176,218,229,11,36,130,225
      DATA 2,176,218,229,11,40,130,225,3,176,218,229,11,44,130,225,22,160,128,226,0,48,218,229,1,176,218,229,11,52,131,225,2,176,218,229,11,56,131,225,3,176,218,229,11,60,131,225
      DATA 3,48,176,225,0,48,99,66,130,64,130,224,3,80,2,226,5,80,132,224,54,0,128,226,0,112,160,227,0,96,160,227,0,176,160,225,0,128,219,229,1,144,219,229,2,160,219,229
      DATA 0,128,193,229,1,144,193,229,2,160,193,229,3,176,139,226,4,16,129,226,1,96,134,226,2,0,86,225,244,255,255,186,5,0,128,224,1,112,135,226,3,0,87,225,238,255,255,186
      DATA 255,159,189,232
      DATA -1

      REM *********************************************************************************************************************

      DATA "digits12x20"
      DATA 96,0,0,0,88,4,0,0,80,8,0,0,72,12,0,0,64,16,0,0,56,20,0,0,48,24,0,0,40,28,0,0,32,32,0,0,24,36,0,0,0,0,66,77,248,3,0,0
      DATA 0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0
      DATA 32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0
      DATA 0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0
      DATA 20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0
      DATA 40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,77,248,3,0,0
      DATA 0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0,0,0,0,0,194,3,0,0
      DATA 32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,66,77,248,3,0,0,0,0,0,0,54,0,0,0,40,0,0,0,12,0,0,0,20,0,0,0,1,0,32,0
      DATA 0,0,0,0,194,3,0,0,32,46,0,0,32,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0
      DATA 0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
      DATA -1
